#"Did the Founding of the Federal Reserve Affect the Vulnerability of the Interbank System to Contagion Risk?"
#JMCB ms. #16-292
#Mark Carlson and David C. Wheelock

#Perform calculations for first principal component of interbank deposit flows
#Creates and exports Figure 1

library(tidyverse)
library(plyr)

rm(list = ls())

#specify directory where folder is stored
dir <- ""
setwd(dir)

#read in variable to insert gap between periods and create sequence to serve as x axis
source("programs/R functions/insert_gap.R")
#read in function to export figures
source("programs/R functions/ExportPlot.R")

#Section 1: Read in data and ready data for principal components analysis
##################################################################################

############### Section 1.1: Read and ready data for country banks ###############

#Read in data file fpr country banks
Country_data <- read.table("data/MS16-292EntirePeriod_states.txt", header = TRUE)
Country_data[is.na(Country_data)] <- 0
Country_data$mark_dt <-as.Date(Country_data$mark_dt,"%m/%d/%Y",origin="01/01/1880")
Country_data <- Country_data[which(Country_data$mark_dt<='1914-09-12' | 
                                   Country_data$mark_dt>='1920-12-29'),]

#Drop observations if location is Dakota, Hawaii, or Indian Territory
#Keep if years are 1894-1914 or 1921-1929
Country_data <- Country_data[!(Country_data$location=="Dakota" | Country_data$location=="Hawaii" | 
                               Country_data$location =="Indian Territory"),]

#Multiply observations for 1911 or later by 1000 so units are consistent across dates 
Country_data[Country_data$mark_dt >'1911-01-01',!names(Country_data) %in% c("mark_dt", "location")] <- 
Country_data[Country_data$mark_dt >'1911-01-01',!names(Country_data) %in% c("mark_dt", "location")]*1000

#Combine df_redeem and df_national into one variable
Country_data$df_redeem_and_national <- Country_data$df_redeem + Country_data$df_national

#Create lag variables used to calculate first difference ratio
Country_data <- ddply(Country_data, .(location), mutate, 
                      lag_df_redeem_and_national=c(NA,head(df_redeem_and_national,-1)),
                      lag_assets=c(NA,head(assets,-1)))

#Calculate first difference to asset ratio
Country_data$df_redeem_and_national_dlt_assets <- 
  with(Country_data, (df_redeem_and_national - lag_df_redeem_and_national)/lag_assets)

#keep first difference to asset ratio
Country_data <- Country_data[c("mark_dt", "location", "df_redeem_and_national_dlt_assets")]

#keep if dates in sample period
Country_data <- Country_data[Country_data$mark_dt >= "1894-02-28",]
Country_data <- Country_data[Country_data$mark_dt <= "1914-09-12" | Country_data$mark_dt >= "1921-02-21",]
Country_data <- Country_data[Country_data$mark_dt <= "1928-06-30",]

#reshapes data
Country_data <- reshape(Country_data, timevar="location", idvar="mark_dt", direction="wide")

############### Section 1.2: Read and ready data for reserve city banks ###############

#Read in data 
RCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
RCities_data[is.na(RCities_data)] <- 0
RCities_data$mark_dt <-as.Date(RCities_data$mark_dt,"%m/%d/%Y",origin="01/01/1880")
#Subset on dates
RCities_data <- RCities_data[which(RCities_data$mark_dt<='1914-09-12' | 
                                   RCities_data$mark_dt>='1920-12-29'),]

#Drop observations if location is Chicago, New York, St. Louis (all central reserve cities) or Indianapolis
RCities_data <- RCities_data[!(RCities_data$location=="Chicago"   | RCities_data$location=="New York" | 
                               RCities_data$location =="St Louis" | RCities_data$location=="Indianapolis"),]

#Multiply observations for 1911 or later by 1000 so units are consistent across dates 
RCities_data[RCities_data$mark_dt >'1911-01-01',!names(RCities_data) %in% c("mark_dt", "location")] <- 
RCities_data[RCities_data$mark_dt >'1911-01-01',!names(RCities_data) %in% c("mark_dt", "location")]*1000

#Net due from reserve agents and other national banks
RCities_data$net_df_redeem_and_national <- 
  with(RCities_data, df_redeem + df_national - dt_redeem - dt_national)

#lag of net due from reserve agents and other national banks
RCities_data <- ddply(RCities_data, .(location), mutate, 
                      lag_net_df_redeem_and_national=c(NA,head(net_df_redeem_and_national,-1)), 
                      lag_assets=c(NA,head(assets,-1)))

#Change in net due from reserve agents and other national banks over assets
RCities_data$net_df_redeem_and_national_dlt_assets <- 
  with(RCities_data, (net_df_redeem_and_national - lag_net_df_redeem_and_national)/lag_assets)

#keep if dates in sample period
RCities_data <- RCities_data[RCities_data$mark_dt >= "1894-02-28",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1914-09-12" | RCities_data$mark_dt >= "1921-02-21",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1928-06-30",]

#Keep necessary variables
RCities_data <- RCities_data[c("mark_dt", "location", "net_df_redeem_and_national_dlt_assets")]

#reshape data
RCities_data <- reshape(RCities_data, timevar="location", idvar="mark_dt", direction="wide")

############### Section 1.3: Read and ready data for central reserve city banks ###############

#Read in data 
CRCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
CRCities_data[is.na(CRCities_data)] <- 0
CRCities_data$mark_dt <-as.Date(CRCities_data$mark_dt,"%m/%d/%Y",origin="01/01/1880")
#subset on date
CRCities_data <- CRCities_data[which(CRCities_data$mark_dt<='1914-09-12' | 
                                     CRCities_data$mark_dt>='1920-12-29'),]

#Keep observations if location is Chicago, New York, St. Louis
CRCities_data <- CRCities_data[(CRCities_data$location=="Chicago" | CRCities_data$location=="New York" | 
                                CRCities_data$location =="St Louis"),]

#Multiply observations for 1911 or later by 1000 so units are consistent across dates
CRCities_data[CRCities_data$mark_dt >'1911-01-01',!names(CRCities_data) %in% c("mark_dt", "location")] <- 
CRCities_data[CRCities_data$mark_dt >'1911-01-01',!names(CRCities_data) %in% c("mark_dt", "location")]*1000

#create lag variables
CRCities_data <- ddply(CRCities_data, .(location), mutate, 
                       lag_dt_national=c(NA,head(dt_national,-1)), 
                       lag_assets=c(NA,head(assets,-1)))

#Change in due to national banks over assets
CRCities_data$dt_national_dlt_assets <- 
  with(CRCities_data, (dt_national - lag_dt_national)/lag_assets)

#keep if dates in sample period
CRCities_data <- CRCities_data[CRCities_data$mark_dt >= "1894-02-28",]
CRCities_data <- CRCities_data[CRCities_data$mark_dt <= "1914-09-12" | CRCities_data$mark_dt >= "1921-02-21",]
CRCities_data <- CRCities_data[CRCities_data$mark_dt <= "1928-06-30",]

#Keep necessary variables
CRCities_data <- CRCities_data[c("mark_dt", "location", "dt_national_dlt_assets")]

#reshape data
CRCities_data <- reshape(CRCities_data, timevar="location", idvar="mark_dt", direction="wide")

#Section 2: Principal components analysis
##################################################################################

###################### Section 2.1: PCA for country banks  #######################

#PCA function
Country_PC <- prcomp(Country_data[!names(Country_data) %in% c("mark_dt", "location")])

#Extracts parts of PCA output
#Summary
Country_PC_summary <- data.frame(t(summary(Country_PC)$importance))
#Rotated data
Country_PC_x <- data.frame(Country_PC$x)
Country_PC_x$mark_dt <- Country_data$mark_dt
Country_PC_x <- Country_PC_x[,c("mark_dt", grep("PC", names(Country_PC_x), value=TRUE))]
#Loadings
Country_PC_loadings <- data.frame(Country_PC$rotation)

#Extract first principal component for chart
Figure1 <- Country_PC_x[,c("mark_dt", "PC1")]
names(Figure1)[names(Figure1)=="PC1"] <- "PC1_df_redeem_and_national_country"

################### Section 2.2: PCA for reserve city banks ####################

#PCA function
RCities_PC <- prcomp(RCities_data[!names(RCities_data) %in% c("mark_dt", "location")])

#Extracts parts of PCA output
#Summary
RCities_PC_summary <- data.frame(t(summary(RCities_PC)$importance))
#Rotated data
RCities_PC_x <- data.frame(RCities_PC$x)
RCities_PC_x$mark_dt <- RCities_data$mark_dt
RCities_PC_x <- RCities_PC_x[,c("mark_dt", grep("PC", names(RCities_PC_x), value=TRUE))]
#Loadings
RCities_PC_loadings <- data.frame(RCities_PC$rotation)

#EXtract first principal component for chart
Figure1 <- merge(Figure1, RCities_PC_x, by="mark_dt")
names(Figure1)[names(Figure1)=="PC1"] <- "PC1_net_df_redeem_and_national_RC"
Figure1 <- Figure1[,c("mark_dt", "PC1_df_redeem_and_national_country", 
                      "PC1_net_df_redeem_and_national_RC")]

############### Section 2.3: PCA for central reserve city banks ################

#PCA function
CRCities_PC <- prcomp(CRCities_data[!names(CRCities_data) %in% c("mark_dt", "location")])

#Extracts parts of PCA output
#Summary
CRCities_PC_summary <- data.frame(t(summary(CRCities_PC)$importance))
#Rotated data
CRCities_PC_x <- data.frame(CRCities_PC$x)
CRCities_PC_x$mark_dt <- CRCities_data$mark_dt
CRCities_PC_x <- CRCities_PC_x[,c("mark_dt", grep("PC", names(CRCities_PC_x), value=TRUE))]
#Loadings
CRCities_PC_loadings <- data.frame(CRCities_PC$rotation)

#EXtract first principal component for chart
Figure1 <- merge(Figure1, CRCities_PC_x, by="mark_dt")
names(Figure1)[names(Figure1)=="PC1"] <- "PC1_dt_national_CRC"

#Section 3: Create figures
##################################################################################
#Keep variables needed for Figure 1
Figure1 <- Figure1[,c("mark_dt", "PC1_df_redeem_and_national_country", 
                      "PC1_net_df_redeem_and_national_RC", 
                      "PC1_dt_national_CRC")]

#call function used to insert gap and create sequence used as x axis in figures
Figure1 <- insert_gap(Figure1)

#specify x axis breaks
xbreaks <- which(as.character(Figure1$mark_dt) %in% 
                c("1894-05-04", "1895-05-07", "1896-05-07",
                  "1897-05-14", "1898-05-05", "1899-06-30",
                  "1900-06-29", "1901-07-15", "1902-07-16", 
                  "1903-06-09", "1904-06-09", "1905-05-29",
                  "1906-06-18", "1907-05-20", "1908-07-15",
                  "1909-06-23", "1910-06-30", "1911-06-07",
                  "1912-06-14", "1913-06-04", "1914-06-30",
                  "1921-06-30", "1922-06-30", "1923-06-30",
                  "1924-06-30", "1925-06-30", "1926-06-30",
                  "1927-06-30", "1928-06-30"))

#specify x axis labels
xlabels=c("1894", "1895", "1896",
          "1897", "1898", "1899",
          "1900", "1901", "1902", 
          "1903", "1904", "1905",
          "1906", "1907", "1908",
          "1909", "1910", "1911",
          "1912", "1913", "1914",
          "1921", "1922", "1923",
          "1924", "1925", "1926",
          "1927", "1928")

#Create Figure 1.A; PC1 for country banks
Figure1.A <-
  #x axis sequence, y axis PC1 of df_redeem_and_national_country
  ggplot(data=Figure1, aes(x=xseq,y=PC1_df_redeem_and_national_country)) +
  #line plot
  geom_line() +
  #x axis breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels) +
  scale_y_continuous(expand=c(0,0), breaks=c(-.3, -.2, -.1, 0, .1, .2, .3)) +
  coord_cartesian(ylim=c(-.3, .3))+
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11))+
  #insert vertical line at gap
  geom_vline(xintercept=107, linetype="dashed")

#Export Figure1.A
ExportPlot(Figure1.A, "output/MS16-292Figure 1-A", width=6.27, height=2.65)

#Create Figure 1.B; PC1 for reserve cities
Figure1.B <-
  #x axis sequence, y axis PC1 of net_df_redeem_and_national_RC
  ggplot(data=Figure1, aes(x=xseq,y=PC1_net_df_redeem_and_national_RC)) +
  #line plot
  geom_line() +
  #x axis breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels) +
  scale_y_continuous(expand=c(0,0), breaks=c(-.2, -.15, -.1, -.05, 0, .05, .1, .15, .2)) +
  coord_cartesian(ylim=c(-.2, .2))+
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11))+
  #insert vertical line at gap
  geom_vline(xintercept=107, linetype="dashed")

#Export Figure1.B
ExportPlot(Figure1.B, "output/MS16-292Figure 1-B", width=6.27, height=2.65)

#Create Figure 1.C; PC1 for central reserve cities
Figure1.C <-
  #x axis sequence, y axis PC1 of dt_national_CRC
  ggplot(data=Figure1, aes(x=xseq,y=PC1_dt_national_CRC)) +
    #line plot
    geom_line() +
    #x axis breaks and labels
    scale_x_continuous(breaks=xbreaks,labels=xlabels) +
    scale_y_continuous(expand=c(0,0), breaks=c(-.1, -.05, 0, .05, .1)) +
    coord_cartesian(ylim=c(-.1, .1))+
    #theme
    theme_classic()+
    theme(text=element_text(family="serif"),
          axis.title.x=element_blank(),
          axis.title.y=element_blank(),
          axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
          axis.text.y = element_text(size = 11))+
    #insert vertical line at gap
    geom_vline(xintercept=107, linetype="dashed")

#Export Figure1.C
ExportPlot(Figure1.C, "output/MS16-292Figure 1-C", width=6.27, height=2.65)
