#"Did the Founding of the Federal Reserve Affect the Vulnerability of the Interbank System to Contagion Risk?"
#JMCB ms. #16-292
#Mark Carlson and David C. Wheelock

#Calculate changes in deposits due from national banks scaled by total assets
#for Southern states and New England and Northwestern states. 
#Creates and exports Figure 2.

library(ggplot2)
library(plyr)
library(reshape)
library(stringr)

rm(list = ls())

#specify directory where folder is stored
dir <- ""
setwd(dir)

#read in variable to insert gap between periods and create sequence to serve as x axis
source("programs/R functions/insert_gap.R")
#read in function to export figures
source("programs/R functions/ExportPlot.R")

#Section 1: Read in and prepare data
##################################################################################

#Read in country bank data
Country_data <- read.table("data/MS16-292EntirePeriod_states.txt", header = TRUE)
Country_data$mark_dt <- as.Date(Country_data$mark_dt, format="%m/%d/%Y")
Country_data[is.na(Country_data)] <- 0

#Multiply observations in 1911 or later to keep units consistent across time
Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)] <- 
  Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)]*1000

#remove spaces from location string
Country_data$location <- str_replace_all(Country_data$location, " ", "")

#Keep locations in "South" and "New England and Northwestern" states and variables needed for ratios
Country_data <- Country_data[Country_data$location %in% 
                               c("California",    "Colorado",      "Connecticut", 
                                 "Idaho",         "Maine",         "Massachusetts",
                                 "Montana",       "NewHampshire",  "Oregon",
                                 "RhodeIsland",   "Vermont",       "Washington",
                                 "Wyoming",       "Alabama",       "Arkansas", 
                                 "Florida",       "Georgia",       "Louisiana", 
                                 "Mississippi",   "NorthCarolina", "Oklahoma", 
                                 "SouthCarolina", "Tennessee",     "Texas"),
                               c("mark_dt", "location", "df_national", "df_redeem", "assets")] 

#Create lag variables used to calculate first differences
Country_data <- ddply(Country_data, .(location), mutate, 
                      lag_df_redeem=c(NA,head(df_redeem,-1)), 
                      lag_df_national=c(NA, head(df_national,-1)), 
                      lag_assets=c(NA,head(assets,-1)))

#keep if date in sample period
Country_data <- Country_data[Country_data$mark_dt >= "1894-02-28",]
Country_data <- Country_data[Country_data$mark_dt <= "1906-11-12",]

#reshape data to wide format
Country_data <- reshape(Country_data, timevar="location", idvar="mark_dt", direction="wide")

#Section 2: Calculate ratio of change in deposits due from national banks for different regions
###############################################################################################

#Sum variables over New England and Northwestern states
Country_data$df_national_NE_NW <- 
  with(Country_data, 
       df_national.California +  df_national.Colorado +     df_national.Connecticut + 
       df_national.Idaho +       df_national.Maine +        df_national.Massachusetts + 
       df_national.Montana +     df_national.NewHampshire + df_national.Oregon + 
       df_national.RhodeIsland + df_national.Vermont +      df_national.Washington + 
       df_national.Wyoming)

Country_data$df_redeem_NE_NW <- 
  with(Country_data, 
       df_redeem.California +  df_redeem.Colorado +     df_redeem.Connecticut + 
       df_redeem.Idaho +       df_redeem.Maine +        df_redeem.Massachusetts + 
       df_redeem.Montana +     df_redeem.NewHampshire + df_redeem.Oregon + 
       df_redeem.RhodeIsland + df_redeem.Vermont +      df_redeem.Washington + 
       df_redeem.Wyoming)

Country_data$lag_df_national_NE_NW <- 
  with(Country_data, 
       lag_df_national.California +  lag_df_national.Colorado +      lag_df_national.Connecticut + 
       lag_df_national.Idaho +       lag_df_national.Maine +         lag_df_national.Massachusetts + 
       lag_df_national.Montana +     lag_df_national.NewHampshire +  lag_df_national.Oregon + 
       lag_df_national.RhodeIsland + lag_df_national.Vermont +       lag_df_national.Washington + 
       lag_df_national.Wyoming)

Country_data$lag_df_redeem_NE_NW <- 
  with(Country_data, 
       lag_df_redeem.California +  lag_df_redeem.Colorado +      lag_df_redeem.Connecticut + 
       lag_df_redeem.Idaho +       lag_df_redeem.Maine +         lag_df_redeem.Massachusetts + 
       lag_df_redeem.Montana +     lag_df_redeem.NewHampshire +  lag_df_redeem.Oregon + 
       lag_df_redeem.RhodeIsland + lag_df_redeem.Vermont +       lag_df_redeem.Washington + 
       lag_df_redeem.Wyoming)

Country_data$lag_assets_NE_NW <- 
  with(Country_data, 
       lag_assets.California +  lag_assets.Colorado +     lag_assets.Connecticut + 
       lag_assets.Idaho +       lag_assets.Maine +        lag_assets.Massachusetts + 
       lag_assets.Montana +     lag_assets.NewHampshire + lag_assets.Oregon + 
       lag_assets.RhodeIsland + lag_assets.Vermont +      lag_assets.Washington + 
       lag_assets.Wyoming)

#Sum variables over Southern states
Country_data$df_national_South <- 
  with(Country_data, 
       df_national.Alabama +       df_national.Arkansas +  df_national.Florida + 
       df_national.Georgia +       df_national.Louisiana + df_national.Mississippi + 
       df_national.NorthCarolina + df_national.Oklahoma +  df_national.SouthCarolina + 
       df_national.Tennessee +     df_national.Texas)

Country_data$df_redeem_South <- 
  with(Country_data, 
       df_redeem.Alabama +       df_redeem.Arkansas +   df_redeem.Florida + 
       df_redeem.Georgia +       df_redeem.Louisiana +  df_redeem.Mississippi + 
       df_redeem.NorthCarolina + df_redeem.Oklahoma +   df_redeem.SouthCarolina + 
       df_redeem.Tennessee +     df_redeem.Texas)

Country_data$lag_df_national_South <- 
  with(Country_data, 
       lag_df_national.Alabama +        lag_df_national.Arkansas +  lag_df_national.Florida + 
       lag_df_national.Georgia +        lag_df_national.Louisiana + lag_df_national.Mississippi + 
       lag_df_national.NorthCarolina +  lag_df_national.Oklahoma +  lag_df_national.SouthCarolina + 
       lag_df_national.Tennessee +      lag_df_national.Texas)

Country_data$lag_df_redeem_South <- 
  with(Country_data, 
       lag_df_redeem.Alabama +       lag_df_redeem.Arkansas +  lag_df_redeem.Florida + 
       lag_df_redeem.Georgia +       lag_df_redeem.Louisiana + lag_df_redeem.Mississippi + 
       lag_df_redeem.NorthCarolina + lag_df_redeem.Oklahoma +  lag_df_redeem.SouthCarolina + 
       lag_df_redeem.Tennessee +     lag_df_redeem.Texas)

Country_data$lag_assets_South <- 
  with(Country_data, 
       lag_assets.Alabama +       lag_assets.Arkansas +  lag_assets.Florida + 
       lag_assets.Georgia +       lag_assets.Louisiana + lag_assets.Mississippi + 
       lag_assets.NorthCarolina + lag_assets.Oklahoma +  lag_assets.SouthCarolina + 
       lag_assets.Tennessee +     lag_assets.Texas)

#calculate ratio for New England and Northwestern states
Country_data$df_national_redeem_assets_NE_NW <- 
  with(Country_data, 
       (df_redeem_NE_NW + df_national_NE_NW - lag_df_redeem_NE_NW - 
       lag_df_national_NE_NW)/lag_assets_NE_NW)

#calculate ratio for Southern states
Country_data$df_national_redeem_assets_South <- 
  with(Country_data, 
       (df_redeem_South + df_national_South - 
       lag_df_redeem_South - lag_df_national_South)/lag_assets_South)

#Keep ratio for each region
Figure2 <- Country_data[,c("mark_dt", "df_national_redeem_assets_NE_NW", "df_national_redeem_assets_South")]

#Section 3: Create and export figure
#################################################################################

#specify axis breaks
xbreaks <- which(as.character(Figure2$mark_dt) %in% 
                   c("1894-05-04", "1895-05-07", "1896-05-07",
                     "1897-05-14", "1898-05-05", "1899-06-30",
                     "1900-06-29", "1901-07-15", "1902-07-16", 
                     "1903-06-09", "1904-06-09", "1905-05-29",
                     "1906-06-18"))

#specify axis labels
xlabels=c("1894", "1895", "1896",
          "1897", "1898", "1899",
          "1900", "1901", "1902", 
          "1903", "1904", "1905",
          "1906")

#Create Figure2
Figure2.1 <- 
  #x axis is sequence from 1 to nrow
  ggplot(data=Figure2, aes(x=1:nrow(Figure2))) +
  #line 1
  geom_line(aes(y=df_national_redeem_assets_South, linetype="Southern states (left)")) +
  #line 2
  geom_line(aes(y=df_national_redeem_assets_NE_NW*2, linetype="New England and Northwestern states (right)"))+
  #specify x axis breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels) +
  #specify y axis breaks and labels
  coord_cartesian(ylim=c(-.08, .12))+
  scale_y_continuous(expand=c(0,0), breaks=c(-.08, -.04, 0, .04, .08, .12),
                     sec.axis = sec_axis(~./2, breaks = c(-.08, -.04, 0, .04, .08, .12)/2)) +
  #specify line types
  scale_linetype_manual(name=element_blank(), values=c("solid", "dashed"))+
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11),
        #legend.text=element_text(size=12),
        legend.position = c(.76, .85))
  
#export Figure 2
ExportPlot(Figure2.1, "output/MS16-292Figure 2", width=6.27, height=3.56)

