#"Did the Founding of the Federal Reserve Affect the Vulnerability of the Interbank System to Contagion Risk?"
#JMCB ms. #16-292
#Mark Carlson and David C. Wheelock

#Calculate vulnerability indices, interconnectedness, and leverage for different bank groups. 
#Creates and exports Figure 3 and Table 4.

library(tidyverse)
library(data.table)
library(reshape2)

rm(list = ls())

#specify directory where folder is stored
dir <- ""
setwd(dir)

#read in function to insert gap between periods and create sequence to serve as x axis
source("programs/R functions/insert_gap.R")
#read in function to export figures
source("programs/R functions/ExportPlot.R")
#read in function to transpose data table used to format Table 4
source("programs/R functions/transp.R")

#Section 1: Read in data for country banks and calculate vulnerability measures
#############################################################################################

################## Section 1.1: Read in country bank data ###################################
Country_data <- read.table("data/MS16-292EntirePeriod_states.txt", header = TRUE)
Country_data$mark_dt <- as.Date(Country_data$mark_dt, format="%m/%d/%Y")

#Multiply observations for 1911 or later by 1000 so units are consistent across dates 
Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)] <- 
  Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)]*1000

#remove space from location string
Country_data$location <- str_replace_all(Country_data$location, " ", "")

#Keep only 48 states
Country_data <- Country_data[Country_data$location != "Dakota" & 
                             Country_data$location != "Hawaii" & 
                             Country_data$location != "IndianTerritory",]

#keep if date in sample period
Country_data <- Country_data[Country_data$mark_dt >= "1890-07-18",]
Country_data <- Country_data[Country_data$mark_dt <= "1914-09-12" | Country_data$mark_dt > "1920-12-29",]
Country_data <- Country_data[Country_data$mark_dt <= "1928-06-30",]

#replace NAs with 0s
Country_data[is.na(Country_data)] <- 0

###################### Section 1.2: Calculate vulnerability measures###########################
#Assets not connected to other banks
Country_data$nsys <- with(Country_data, assets-df_redeem-df_national-df_state)
#net worth
Country_data$net_worth <- with(Country_data, capital+surplus+Undiv_pro)
#leverage
Country_data$lamb <- with(Country_data, nsys/net_worth)
#interconnectedness
Country_data$beta <- with(Country_data, (dt_national+dt_state+dt_savings+dt_redeem)/(assets-net_worth))
#Keep variables needed
Country_data <- Country_data[,c("mark_dt", "location", "nsys", "net_worth", "lamb", "beta")]

#reshape data wide
Country_data <- reshape(Country_data, timevar="location", idvar="mark_dt", direction="wide")

#sum net worth over states
Country_data$net_worth_country <- 
  with(Country_data, 
       net_worth.Alabama+       net_worth.Arizona+      net_worth.Arkansas+
       net_worth.California+    net_worth.Colorado+     net_worth.Connecticut+
       net_worth.Delaware+      net_worth.Florida+      net_worth.Georgia+
       net_worth.Idaho+         net_worth.Illinois+     net_worth.Indiana+
       net_worth.Iowa+          net_worth.Kansas+       net_worth.Kentucky+
       net_worth.Louisiana+     net_worth.Maine+        net_worth.Maryland+
       net_worth.Massachusetts+ net_worth.Michigan+     net_worth.Minnesota+
       net_worth.Missouri+      net_worth.Montana+      net_worth.Nebraska+
       net_worth.Nevada+        net_worth.NewHampshire+ net_worth.NewJersey+
       net_worth.NewMexico+     net_worth.NewYork+      net_worth.NorthCarolina+
       net_worth.NorthDakota+   net_worth.Ohio+         net_worth.Oklahoma+
       net_worth.Oregon+        net_worth.Pennsylvania+ net_worth.RhodeIsland+
       net_worth.SouthCarolina+ net_worth.SouthDakota+  net_worth.Tennessee+
       net_worth.Texas+         net_worth.Utah+         net_worth.Vermont+
       net_worth.Virginia+      net_worth.Washington+   net_worth.WestVirginia+
       net_worth.Wisconsin+     net_worth.Wyoming+      net_worth.Mississippi)

#average net worth over 48 states
Country_data$avenw_country <- Country_data$net_worth_country/48

#harmonic mean of leverage measure
Country_data$hrmlm_country <- 
  with(Country_data, 
      1/((1/lamb.Alabama +       1/lamb.Arizona +       1/lamb.Arkansas + 
          1/lamb.California +    1/lamb.Colorado +      1/lamb.Connecticut +
          1/lamb.Delaware +      1/lamb.Florida +       1/lamb.Georgia + 
          1/lamb.Idaho +         1/lamb.Illinois +      1/lamb.Indiana +
          1/lamb.Iowa +          1/lamb.Kansas +        1/lamb.Kentucky + 
          1/lamb.Louisiana +     1/lamb.Maine +         1/lamb.Maryland +
          1/lamb.Massachusetts + 1/lamb.Michigan +      1/lamb.Minnesota + 
          1/lamb.Mississippi +   1/lamb.Missouri +      1/lamb.Montana + 
          1/lamb.Nebraska +      1/lamb.Nevada +        1/lamb.NewHampshire + 
          1/lamb.NewJersey +     1/lamb.NewMexico +     1/lamb.NewYork + 
          1/lamb.NorthCarolina + 1/lamb.NorthDakota +   1/lamb.Ohio + 
          1/lamb.Oklahoma +      1/lamb.Oregon +        1/lamb.Pennsylvania + 
          1/lamb.RhodeIsland +   1/lamb.SouthCarolina + 1/lamb.SouthDakota + 
          1/lamb.Tennessee +     1/lamb.Texas +         1/lamb.Utah + 
          1/lamb.Vermont +       1/lamb.Virginia +      1/lamb.Washington + 
          1/lamb.WestVirginia +  1/lamb.Wisconsin +     1/lamb.Wyoming)/48))

#average vulnerability measure for country banks
Country_data$avg_vulnerability_country <- with(Country_data, avenw_country*hrmlm_country)

#Section 2: Read in data for reserve city and central reserve city banks and calculate vulnerability measures
#############################################################################################

################## Section 2.1: Read in reserve city bank data ###################################
#Read in reserve cities data
RCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
RCities_data$mark_dt <- as.Date(RCities_data$mark_dt, format="%m/%d/%Y")

#Multiply observations for 1911 or later by 1000 so units are consistent across dates 
RCities_data[RCities_data$mark_dt >= "1911-01-01",3:ncol(RCities_data)] <- 
  RCities_data[RCities_data$mark_dt >= "1911-01-01",3:ncol(RCities_data)]*1000

#remove space from location string
RCities_data$location <- str_replace_all(RCities_data$location, " ", "")

#keep 18 reserve cities and 3 central reserve cities
RCities_data <- RCities_data[RCities_data$location != "Indianapolis",]

#rename New York City's location
RCities_data$location[RCities_data$location=="NewYork"] <- "NewYorkCity"

#keep if dates in sample period
RCities_data <- RCities_data[RCities_data$mark_dt >= "1890-07-18",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1914-09-12" | 
                             RCities_data$mark_dt  > "1920-12-29",]

RCities_data <- RCities_data[RCities_data$mark_dt <= "1928-06-30",]

#replace NAs with 0
RCities_data[is.na(RCities_data)] <- 0

###################### Section 2.2: Calculate vulnerability measures###########################
#assets not connected to other bank
RCities_data$nsys <- with(RCities_data, assets-df_redeem-df_national-df_state)
#net worth
RCities_data$net_worth <- with(RCities_data, capital+surplus+Undiv_pro)
#leverage
RCities_data$lamb <- with(RCities_data, nsys/net_worth)
#interconnectedness
RCities_data$beta <- with(RCities_data, (dt_national+dt_state+dt_savings+dt_redeem)/(assets-net_worth))

#Keep variables needed
RCities_data <- RCities_data[,c("mark_dt", "location", "nsys", "net_worth", "lamb", "beta")]

#reshape data wide
RCities_data <- reshape(RCities_data, timevar="location", idvar="mark_dt", direction="wide")

#sum of net worth for reserve city banks
RCities_data$net_worth_reserve_city <- 
  with(RCities_data, 
       net_worth.Albany+       net_worth.Baltimore+  net_worth.Boston+
       net_worth.Cincinnati+   net_worth.Cleveland+  net_worth.Detroit+
       net_worth.KansasCityM+  net_worth.Louisville+ net_worth.Milwaukee+
       net_worth.Minneapolis+  net_worth.NewOrleans+ net_worth.Omaha+
       net_worth.Philadelphia+ net_worth.Pittsburgh+ net_worth.SanFrancisco+
       net_worth.StJoseph+     net_worth.StPaul+     net_worth.Washington)

#average net worth for the 18 reserve cities
RCities_data$avenw_reserve_city <- RCities_data$net_worth_reserve_city/18

#harmonic mean of leverage
RCities_data$hrmlm_reserve_city <- 
  with(RCities_data, 
       1/((1/lamb.Albany +       1/lamb.Baltimore +  1/lamb.Boston + 
           1/lamb.Cincinnati +   1/lamb.Cleveland +  1/lamb.Detroit +
           1/lamb.KansasCityM +  1/lamb.Louisville + 1/lamb.Milwaukee + 
           1/lamb.Minneapolis +  1/lamb.NewOrleans + 1/lamb.Omaha +
           1/lamb.Philadelphia + 1/lamb.Pittsburgh + 1/lamb.SanFrancisco + 
           1/lamb.StJoseph +     1/lamb.StPaul +     1/lamb.Washington)/18))

#average vulnerability index for reserve cities
RCities_data$avg_vulnerability_reserve_city <- 
  with(RCities_data, avenw_reserve_city*hrmlm_reserve_city)

#Section 3: Calculate vulnerability measures used in figure and table
##################################################################################################

#combine data for country banks and cities into single data frame
vulnerability_index_data <- merge(Country_data, RCities_data, by="mark_dt")

#contagion index NYC
vulnerability_index_data$contagion_index_NYC <- 
  with(vulnerability_index_data, net_worth.NewYorkCity*beta.NewYorkCity*(lamb.NewYorkCity-1))

#contagion index Chicago
vulnerability_index_data$contagion_index_Chicago <- 
  with(vulnerability_index_data, net_worth.Chicago*beta.Chicago*(lamb.Chicago-1))

#vulnerability index NYC for country banks
vulnerability_index_data$vulnerability_index_country_NYC <- 
  with(vulnerability_index_data, contagion_index_NYC/avg_vulnerability_country)

#vulnerability index chicago for country banks
vulnerability_index_data$vulnerability_index_country_Chicago <- 
  with(vulnerability_index_data, contagion_index_Chicago/avg_vulnerability_country)

#Vulnerability index for NYC and Chicago
vulnerability_index_data$vulnerability_index_reserve_city_NYC <- 
  with(vulnerability_index_data, contagion_index_NYC/avg_vulnerability_reserve_city)

vulnerability_index_data$vulnerability_index_reserve_city_Chicago <- 
  with(vulnerability_index_data, contagion_index_Chicago/avg_vulnerability_reserve_city)


#Section 4: Create Figure 3
####################################################################################################
#Variables needed for figure
Figure3 <- vulnerability_index_data[, 
            c("mark_dt", "vulnerability_index_country_NYC", "vulnerability_index_country_Chicago", 
              "vulnerability_index_reserve_city_NYC", "vulnerability_index_reserve_city_Chicago")]

#call function used to insert gap and create sequence used as x axis in figures
Figure3 <- insert_gap(Figure3)

#x axis breaks
xbreaks <- which(as.character(Figure3$mark_dt) %in% 
                   c("1890-07-18", "1891-05-04", "1892-05-17",
                     "1893-05-04", "1894-05-04", "1895-05-07", 
                     "1896-05-07", "1897-05-14", "1898-05-05", 
                     "1899-06-30", "1900-06-29", "1901-07-15", 
                     "1902-07-16", "1903-06-09", "1904-06-09", 
                     "1905-05-29", "1906-06-18", "1907-05-20", 
                     "1908-07-15", "1909-06-23", "1910-06-30", 
                     "1911-06-07", "1912-06-14", "1913-06-04", 
                     "1914-06-30", "1921-06-30", "1922-06-30", 
                     "1923-06-30", "1924-06-30", "1925-06-30", 
                     "1926-06-30", "1927-06-30", "1928-06-30"))

#x axis labels
xlabels=c("1890", "1891", "1892",
          "1893", "1894", "1895", 
          "1896", "1897", "1898", 
          "1899", "1900", "1901", 
          "1902", "1903", "1904", 
          "1905", "1906", "1907", 
          "1908", "1909", "1910", 
          "1911", "1912", "1913", 
          "1914", "1921", "1922", 
          "1923", "1924", "1925", 
          "1926", "1927", "1928")

#reshape figure 3 data for use in ggplot
Figure3 <- melt(Figure3, id.vars = c("mark_dt", "xseq"))

#create Figure 3.1
Figure3.1 <- 
  #variables plotted in Figure 3.1
  ggplot(data=Figure3[Figure3$variable=="vulnerability_index_country_NYC" |
                    Figure3$variable=="vulnerability_index_country_Chicago",],
         #x axis is sequence, y axis value of variable, and different linetype for each variable
         aes(x=xseq,y=value,linetype=variable)) +
  #line plot
  geom_line() +

  #specify x axis breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels) +
  #specify y axis breaks
  scale_y_continuous(expand=c(0,0), breaks=c(0, 2, 4, 6, 8, 10, 12)) +
  coord_cartesian(ylim=c(0, 12))+
  #line type/legend
  scale_linetype_manual(labels=c("New York City", "Chicago"), values=c("solid", "dashed"))+
  #theme/design
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11),
        legend.position = c(.9,.9),
        #legend.text = element_text(size=14),
        legend.title = element_blank())+
  #insert vertical dashed line to separate periods
  geom_vline(xintercept=125, linetype="dashed")

#export Figure 3.1
ExportPlot(Figure3.1, "output/MS16-292Figure 3-A", width=6.27, height=3.46)

#Create Figure 3.2
Figure3.2 <- 
  #variables plotted in Figure 3.2
  ggplot(data=Figure3[Figure3$variable=="vulnerability_index_reserve_city_NYC" |
                      Figure3$variable=="vulnerability_index_reserve_city_Chicago",],
         #x axis is sequence, y axis value of variable, and different linetype for each variable
         aes(x=xseq,y=value,linetype=variable)) +
  #line plot
  geom_line() +
  #specify y axis breaks
  scale_y_continuous(expand=c(0,0), breaks=c(0, 2, 4, 6, 8, 10, 12)) +
  coord_cartesian(ylim=c(0, 12))+
  #specify x axis breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels) +
  #line type/legend
  scale_linetype_manual(labels=c("New York City", "Chicago"), values=c("solid", "dashed"))+
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11),
        legend.position = c(.9,.9),
        #legend.text = element_text(size=14),
        legend.title = element_blank())+
  #insert vertical dashed line to separate periods
  geom_vline(xintercept=125, linetype="dashed")

#export Figure 3.2
ExportPlot(Figure3.2, "output/MS16-292Figure 3-B", width=6.27, height=3.46)

#Section 5: Create Table 4
####################################################################################################
#keep variables needed for Table 4
table4 <- vulnerability_index_data[,
             c("mark_dt", "vulnerability_index_country_NYC", "vulnerability_index_country_Chicago",
               "vulnerability_index_reserve_city_NYC", "vulnerability_index_reserve_city_Chicago",
               "beta.NewYorkCity", "beta.Chicago", "hrmlm_country", "hrmlm_reserve_city",
               "lamb.NewYorkCity", "lamb.Chicago")]

#create period variable used to group observations
table4$period <- "1890-1914"
table4[table4$mark_dt >="1921-02-21",]$period <- "1921-1928"

#function to calculate z statistic for wilcoxon rank test
wilcox_z <- function(vector1, vector2){
  obs1 <- length(vector1)
  obs2 <- length(vector2)
  mu <- (obs1*obs2)/2
  std <- sqrt(obs1*obs2*(obs1+obs2+1)/12)
  test <- wilcox.test(vector1, vector2)
  w <- test$statistic
  z <- (w - mu)/std
  
  p <- test$p.value
  
  if(p > .05 & p <= .1){
    z <- paste0(round(z,1), "*")
  }
  
  if(p > .01 & p <= .05){
    z <- paste0(round(z,1), "**")
  }
  
  if(p <=.01){
    z <- paste0(round(z,1), "***")
  }
  
return(z)
}

#perform wilcoxon rank test for specified variables with groups defined by period
vulnerability_index_country_NYC_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "vulnerability_index_country_NYC"],
           table4[table4$period=="1890-1914", "vulnerability_index_country_NYC"])

vulnerability_index_country_Chicago_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "vulnerability_index_country_Chicago"],
           table4[table4$period=="1890-1914", "vulnerability_index_country_Chicago"])

vulnerability_index_reserve_city_NYC_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "vulnerability_index_reserve_city_NYC"],
           table4[table4$period=="1890-1914", "vulnerability_index_reserve_city_NYC"])

vulnerability_index_reserve_city_Chicago_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "vulnerability_index_reserve_city_Chicago"],
           table4[table4$period=="1890-1914", "vulnerability_index_reserve_city_Chicago"])

beta.NewYorkCity_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "beta.NewYorkCity"],
           table4[table4$period=="1890-1914", "beta.NewYorkCity"])

beta.Chicago_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "beta.Chicago"],
           table4[table4$period=="1890-1914", "beta.Chicago"])

hrmlm_country_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "hrmlm_country"],
           table4[table4$period=="1890-1914", "hrmlm_country"])

hrmlm_reserve_city_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "hrmlm_reserve_city"],
           table4[table4$period=="1890-1914", "hrmlm_reserve_city"])

lamb.NewYorkCity_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "lamb.NewYorkCity"],
           table4[table4$period=="1890-1914", "lamb.NewYorkCity"])

lamb.Chicago_Z <-
  wilcox_z(table4[table4$period=="1921-1928", "lamb.Chicago"],
           table4[table4$period=="1890-1914", "lamb.Chicago"])

#convert table 4 to data.table
table4 <- as.data.table(table4)

#calculate means and standard deviations of variables by period
table4 <- 
  table4[, 
   .('Vul. Index: Country banks with respect to New York City (Mean)'=mean(vulnerability_index_country_NYC),
     'Vul. Index: Country banks with respect to New York City (SD)'=sd(vulnerability_index_country_NYC),
     'Vul. Index: Country banks with respect to Chicago (Mean)'=mean(vulnerability_index_country_Chicago),
     'Vul. Index: Country banks with respect to Chicago (SD)'=sd(vulnerability_index_country_Chicago),
     'Vul. Index: Reserve city banks with respect to New York City (Mean)'=mean(vulnerability_index_reserve_city_NYC),
     'Vul. Index: Reserve city banks with respect to New York City (SD)'=sd(vulnerability_index_reserve_city_NYC),
     'Vul. Index: Reserve city banks with respect to Chicago (Mean)'=mean(vulnerability_index_reserve_city_Chicago),
     'Vul. Index: Reserve city banks with respect to Chicago (SD)'=sd(vulnerability_index_reserve_city_Chicago),
     'Interconnectedness: New York City banks (Mean)'=mean(beta.NewYorkCity),
     'Interconnectedness: New York City banks (SD)'=sd(beta.NewYorkCity),
     'Interconnectedness: Chicago banks (Mean)'=mean(beta.Chicago),
     'Interconnectedness: Chicago banks (SD)'=sd(beta.Chicago),
     'Leverage: Country banks (Mean)'=mean(hrmlm_country),
     'Leverage: Country banks (SD)'=sd(hrmlm_country),
     'Leverage: Reserve city banks (Mean)'=mean(hrmlm_reserve_city),
     'Leverage: Reserve city banks (SD)'=sd(hrmlm_reserve_city),
     'Leverage: New York City banks (Mean)'=mean(lamb.NewYorkCity),
     'Leverage: New York City banks banks (SD)'=sd(lamb.NewYorkCity),
     'Leverage: Chicago banks (Mean)'=mean(lamb.Chicago),
     'Leverage: Chicago banks banks (SD)'=sd(lamb.Chicago)), by=period]

#transpose table 4
table4 <- transp(table4)

#convert table 4 back to data frame
table4 <- as.data.frame(table4)

#create test statistics variable
table4$'Test statistic for difference' <- NA

#plug z statistics into table 4
table4[row.names(table4)=="Vul. Index: Country banks with respect to New York City (Mean)", 
       "Test statistic for difference"] <- vulnerability_index_country_NYC_Z

table4[row.names(table4)=="Vul. Index: Country banks with respect to Chicago (Mean)", 
       "Test statistic for difference"] <- vulnerability_index_country_Chicago_Z

table4[row.names(table4)=="Vul. Index: Reserve city banks with respect to New York City (Mean)", 
       "Test statistic for difference"] <- vulnerability_index_reserve_city_NYC_Z

table4[row.names(table4)=="Vul. Index: Reserve city banks with respect to Chicago (Mean)", 
       "Test statistic for difference"] <- vulnerability_index_reserve_city_Chicago_Z

table4[row.names(table4)=="Interconnectedness: New York City banks (Mean)", 
       "Test statistic for difference"] <- beta.NewYorkCity_Z

table4[row.names(table4)=="Interconnectedness: Chicago banks (Mean)", 
       "Test statistic for difference"] <- beta.Chicago_Z

table4[row.names(table4)=="Leverage: Country banks (Mean)", 
       "Test statistic for difference"] <- hrmlm_country_Z

table4[row.names(table4)=="Leverage: Reserve city banks (Mean)", 
       "Test statistic for difference"] <- hrmlm_reserve_city_Z

table4[row.names(table4)=="Leverage: New York City banks (Mean)", 
       "Test statistic for difference"] <- lamb.NewYorkCity_Z

table4[row.names(table4)=="Leverage: Chicago banks (Mean)", 
       "Test statistic for difference"] <- lamb.Chicago_Z

#export table 4
write.csv(table4, file = "output/MS16-292Table 4.csv")