#"Did the Founding of the Federal Reserve Affect the Vulnerability of the Interbank System to Contagion Risk?"
#JMCB ms. #16-292
#Mark Carlson and David C. Wheelock

#Calculate ratios involving required reserves and liquid assets
#Creates and exports Figures 4 and 5. 

library(tidyverse)
library(reshape2)

rm(list = ls())

#specify directory where folder is stored
dir <- ""
setwd(dir)

#read in function to insert gap between periods and create sequence to serve as x axis
source("programs/R functions/insert_gap.R")
#read in function to export figures
source("programs/R functions/ExportPlot.R")

#Section 1: Read in data for country banks and calculate ratios
####################################################################################################################
 
#Read in country bank data
Country_data <- read.table("data/MS16-292EntirePeriod_states.txt", header = TRUE)
Country_data$mark_dt <- as.Date(Country_data$mark_dt, format="%m/%d/%Y")

#Multiply observations for 1911 or later by 1000 so units are consistent across dates
Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)] <- 
  Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)]*1000

#remove space from location string
Country_data$location <- str_replace_all(Country_data$location, " ", "")

#keep only the 48 states
Country_data <- Country_data[Country_data$location != "Dakota" & 
                             Country_data$location != "Hawaii" & 
                             Country_data$location != "IndianTerritory",]

#Replace NAs with 0s
Country_data[is.na(Country_data)] <- 0

#keep if dates in sample period
Country_data <- Country_data[Country_data$mark_dt >= "1894-02-28",]
Country_data <- Country_data[Country_data$mark_dt <= "1914-09-12" | 
                             Country_data$mark_dt >= "1921-02-21",]
Country_data <- Country_data[Country_data$mark_dt <= "1928-06-30",]

#Calculates required reserves for specified date ranges
Country_data$required_reserves <- NA
  #1894 to 1914
Country_data[Country_data$mark_dt>="1894-02-28" & Country_data$mark_dt<"1914-12-31",]$required_reserves <- 
  with(Country_data[Country_data$mark_dt>="1894-02-28" & Country_data$mark_dt<"1914-12-31",], 
        0.15*(inddep + US_dep + US_dispurse + 
        pmax(0, dt_national + dt_state + dt_savings + dt_redeem-
        df_redeem - df_national - df_state) - clearinghouse_exchg -
        0.5*(cash_items) - obank_bills) - Fivepct_fund)
  #1921 to 1928
Country_data[Country_data$mark_dt>="1921-02-21",]$required_reserves <- 
  with(Country_data[Country_data$mark_dt>="1921-02-21",], 
        0.07*(Demand_deposits) + 0.03*(Time_deposits) + 
        0.07*(pmax(0, dt_national + dt_state + dt_non_national + Certified_checks_outstanding +
        Cashiers_checks_on_own_bank_outstanding - df_national - df_state - df_non_national -
        Items_with_Fed_in_process_of_collection - clearinghouse_exchg - 
        Checks_on_other_banks_in_same_place)))

#calculates liquid assets
Country_data$liquid_assets <- 
  with(Country_data, 
       df_redeem + df_national + DuefromFed + Checks_on_other_banks_in_same_place +
       Outside_checks_other_cash_items + cash_items + obank_bills + frac_curr + 
       specie + legaltender + US_CD + vault.cash)

#calculates excess liquid assets
Country_data$excess_liquid_assets <-
  with(Country_data, 
       liquid_assets - required_reserves)

#calculates required reserves to assets ratio
Country_data$required_reserves_to_assets <-
  with(Country_data, required_reserves/assets)

#calculates excess liquid assets to assets ratio
Country_data$excess_liquid_assets_to_assets <-
  with(Country_data, excess_liquid_assets/assets)

#calculates required reserves to liquid assets ratio
Country_data$required_reserves_to_liquid_assets <-
  with(Country_data, required_reserves/liquid_assets)

#keep variables needed
Country_data <- Country_data[,c("mark_dt", "location", "required_reserves_to_assets",
                                "excess_liquid_assets_to_assets", "required_reserves_to_liquid_assets")]

#reshapes data
Country_data <- reshape(Country_data, timevar="location", idvar="mark_dt", direction="wide")

#required reserves to assets pooled ratio
Country_data$required_reserves_to_assets_country <- 
  rowMeans(Country_data[,c("required_reserves_to_assets.Alabama",
                           "required_reserves_to_assets.Arizona",       "required_reserves_to_assets.Arkansas",
                           "required_reserves_to_assets.California",    "required_reserves_to_assets.Colorado",
                           "required_reserves_to_assets.Connecticut",   "required_reserves_to_assets.Delaware",
                           "required_reserves_to_assets.Florida",       "required_reserves_to_assets.Georgia",
                           "required_reserves_to_assets.Idaho",         "required_reserves_to_assets.Illinois",
                           "required_reserves_to_assets.Indiana",       "required_reserves_to_assets.Iowa", 
                           "required_reserves_to_assets.Kansas",        "required_reserves_to_assets.Kentucky",
                           "required_reserves_to_assets.Louisiana",     "required_reserves_to_assets.Maine", 
                           "required_reserves_to_assets.Maryland",      "required_reserves_to_assets.Massachusetts",
                           "required_reserves_to_assets.Michigan",      "required_reserves_to_assets.Minnesota",
                           "required_reserves_to_assets.Mississippi",   "required_reserves_to_assets.Missouri", 
                           "required_reserves_to_assets.Montana",       "required_reserves_to_assets.Nebraska",
                           "required_reserves_to_assets.Nevada",        "required_reserves_to_assets.NewHampshire", 
                           "required_reserves_to_assets.NewJersey",     "required_reserves_to_assets.NewMexico",
                           "required_reserves_to_assets.NewYork",       "required_reserves_to_assets.NorthCarolina",
                           "required_reserves_to_assets.NorthDakota",   "required_reserves_to_assets.Ohio", 
                           "required_reserves_to_assets.Oklahoma",      "required_reserves_to_assets.Oregon", 
                           "required_reserves_to_assets.Pennsylvania",  "required_reserves_to_assets.RhodeIsland",
                           "required_reserves_to_assets.SouthCarolina", "required_reserves_to_assets.SouthDakota", 
                           "required_reserves_to_assets.Tennessee",     "required_reserves_to_assets.Texas", 
                           "required_reserves_to_assets.Utah",          "required_reserves_to_assets.Vermont", 
                           "required_reserves_to_assets.Virginia",      "required_reserves_to_assets.Washington",
                           "required_reserves_to_assets.WestVirginia",  "required_reserves_to_assets.Wisconsin", 
                           "required_reserves_to_assets.Wyoming")])

#excess liquid assets to assets pooled ratio
Country_data$excess_liquid_assets_to_assets_country <- 
  rowMeans(Country_data[,c("excess_liquid_assets_to_assets.Alabama",
                           "excess_liquid_assets_to_assets.Arizona",       "excess_liquid_assets_to_assets.Arkansas",
                           "excess_liquid_assets_to_assets.California",    "excess_liquid_assets_to_assets.Colorado",
                           "excess_liquid_assets_to_assets.Connecticut",   "excess_liquid_assets_to_assets.Delaware",
                           "excess_liquid_assets_to_assets.Florida",       "excess_liquid_assets_to_assets.Georgia",
                           "excess_liquid_assets_to_assets.Idaho",         "excess_liquid_assets_to_assets.Illinois",
                           "excess_liquid_assets_to_assets.Indiana",       "excess_liquid_assets_to_assets.Iowa", 
                           "excess_liquid_assets_to_assets.Kansas",        "excess_liquid_assets_to_assets.Kentucky",
                           "excess_liquid_assets_to_assets.Louisiana",     "excess_liquid_assets_to_assets.Maine", 
                           "excess_liquid_assets_to_assets.Maryland",      "excess_liquid_assets_to_assets.Massachusetts",
                           "excess_liquid_assets_to_assets.Michigan",      "excess_liquid_assets_to_assets.Minnesota",
                           "excess_liquid_assets_to_assets.Mississippi",   "excess_liquid_assets_to_assets.Missouri", 
                           "excess_liquid_assets_to_assets.Montana",       "excess_liquid_assets_to_assets.Nebraska",
                           "excess_liquid_assets_to_assets.Nevada",        "excess_liquid_assets_to_assets.NewHampshire", 
                           "excess_liquid_assets_to_assets.NewJersey",     "excess_liquid_assets_to_assets.NewMexico",
                           "excess_liquid_assets_to_assets.NewYork",       "excess_liquid_assets_to_assets.NorthCarolina",
                           "excess_liquid_assets_to_assets.NorthDakota",   "excess_liquid_assets_to_assets.Ohio", 
                           "excess_liquid_assets_to_assets.Oklahoma",      "excess_liquid_assets_to_assets.Oregon", 
                           "excess_liquid_assets_to_assets.Pennsylvania",  "excess_liquid_assets_to_assets.RhodeIsland",
                           "excess_liquid_assets_to_assets.SouthCarolina", "excess_liquid_assets_to_assets.SouthDakota", 
                           "excess_liquid_assets_to_assets.Tennessee",     "excess_liquid_assets_to_assets.Texas", 
                           "excess_liquid_assets_to_assets.Utah",          "excess_liquid_assets_to_assets.Vermont", 
                           "excess_liquid_assets_to_assets.Virginia",      "excess_liquid_assets_to_assets.Washington",
                           "excess_liquid_assets_to_assets.WestVirginia",  "excess_liquid_assets_to_assets.Wisconsin", 
                           "excess_liquid_assets_to_assets.Wyoming")])

#required reserves to liquid assets pooled ratio
Country_data$required_reserves_to_liquid_assets_country <- 
  rowMeans(Country_data[,c("required_reserves_to_liquid_assets.Alabama",
                           "required_reserves_to_liquid_assets.Arizona",       "required_reserves_to_liquid_assets.Arkansas",
                           "required_reserves_to_liquid_assets.California",    "required_reserves_to_liquid_assets.Colorado",
                           "required_reserves_to_liquid_assets.Connecticut",   "required_reserves_to_liquid_assets.Delaware",
                           "required_reserves_to_liquid_assets.Florida",       "required_reserves_to_liquid_assets.Georgia",
                           "required_reserves_to_liquid_assets.Idaho",         "required_reserves_to_liquid_assets.Illinois",
                           "required_reserves_to_liquid_assets.Indiana",       "required_reserves_to_liquid_assets.Iowa", 
                           "required_reserves_to_liquid_assets.Kansas",        "required_reserves_to_liquid_assets.Kentucky",
                           "required_reserves_to_liquid_assets.Louisiana",     "required_reserves_to_liquid_assets.Maine", 
                           "required_reserves_to_liquid_assets.Maryland",      "required_reserves_to_liquid_assets.Massachusetts",
                           "required_reserves_to_liquid_assets.Michigan",      "required_reserves_to_liquid_assets.Minnesota",
                           "required_reserves_to_liquid_assets.Mississippi",   "required_reserves_to_liquid_assets.Missouri", 
                           "required_reserves_to_liquid_assets.Montana",       "required_reserves_to_liquid_assets.Nebraska",
                           "required_reserves_to_liquid_assets.Nevada",        "required_reserves_to_liquid_assets.NewHampshire", 
                           "required_reserves_to_liquid_assets.NewJersey",     "required_reserves_to_liquid_assets.NewMexico",
                           "required_reserves_to_liquid_assets.NewYork",       "required_reserves_to_liquid_assets.NorthCarolina",
                           "required_reserves_to_liquid_assets.NorthDakota",   "required_reserves_to_liquid_assets.Ohio", 
                           "required_reserves_to_liquid_assets.Oklahoma",      "required_reserves_to_liquid_assets.Oregon", 
                           "required_reserves_to_liquid_assets.Pennsylvania",  "required_reserves_to_liquid_assets.RhodeIsland",
                           "required_reserves_to_liquid_assets.SouthCarolina", "required_reserves_to_liquid_assets.SouthDakota", 
                           "required_reserves_to_liquid_assets.Tennessee",     "required_reserves_to_liquid_assets.Texas", 
                           "required_reserves_to_liquid_assets.Utah",          "required_reserves_to_liquid_assets.Vermont", 
                           "required_reserves_to_liquid_assets.Virginia",      "required_reserves_to_liquid_assets.Washington",
                           "required_reserves_to_liquid_assets.WestVirginia",  "required_reserves_to_liquid_assets.Wisconsin", 
                           "required_reserves_to_liquid_assets.Wyoming")])

#Data for Figures 4 and 5
Figure4_5 <- Country_data[, c("mark_dt", 
                              "required_reserves_to_assets_country", 
                              "excess_liquid_assets_to_assets_country", 
                              "required_reserves_to_liquid_assets_country")]

#Section 2: Read in data for reserve city banks and calculate ratios
####################################################################################################################

#read in reserve cities data
RCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
RCities_data$mark_dt <- as.Date(RCities_data$mark_dt, format="%m/%d/%Y")

#Multiply observations for 1911 or later by 1000 so units are consistent across dates
RCities_data[RCities_data$mark_dt >= "1911-01-01",3:ncol(RCities_data)] <- 
  RCities_data[RCities_data$mark_dt >= "1911-01-01",3:ncol(RCities_data)]*1000

#remove space from location string
RCities_data$location <- str_replace_all(RCities_data$location, " ", "")

#Keep 18 reserve cities analyzed in paper
RCities_data <- RCities_data[RCities_data$location != "Indianapolis" & 
                             RCities_data$location != "Chicago" & 
                             RCities_data$location != "NewYork",]

#replace NAs with 0s
RCities_data[is.na(RCities_data)] <- 0

#keep if dates in sample period
RCities_data <- RCities_data[RCities_data$mark_dt >= "1894-02-28",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1914-09-12" | 
                             RCities_data$mark_dt >= "1921-02-21",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1928-06-30",]

#Calculates required reserves for specified date ranges
RCities_data$required_reserves <- NA
  #1894 to 1914
RCities_data[RCities_data$mark_dt>="1894-02-28" & RCities_data$mark_dt< "1914-12-31",]$required_reserves <- 
  with(RCities_data[RCities_data$mark_dt>="1894-02-28" & RCities_data$mark_dt<"1914-12-31",], 
       0.25*(inddep + US_dep + US_dispurse + 
       pmax(0, dt_national + dt_state + dt_savings + dt_redeem -
       df_redeem - df_national - df_state) - clearinghouse_exchg -
       0.5*(cash_items) - obank_bills) - Fivepct_fund)
  #1921 to 1928
RCities_data[RCities_data$mark_dt>="1921-02-21",]$required_reserves <- 
  with(RCities_data[RCities_data$mark_dt>="1921-02-21",], 
       0.1*(Demand_deposits) + 0.03*(Time_deposits) + 
       0.1*(pmax(0, dt_national + dt_state + dt_non_national + Certified_checks_outstanding +
       Cashiers_checks_on_own_bank_outstanding - df_national - df_state - df_non_national -
       Items_with_Fed_in_process_of_collection - clearinghouse_exchg - 
       Checks_on_other_banks_in_same_place)))

#calculates liquid assets
RCities_data$liquid_assets <- 
  with(RCities_data, 
       df_redeem + df_national + DuefromFed + Checks_on_other_banks_in_same_place +
       Outside_checks_other_cash_items + cash_items + obank_bills + frac_curr + 
       specie + legaltender + US_CD+vault.cash)

#calculates excess liquid assets
RCities_data$excess_liquid_assets <-
  with(RCities_data, liquid_assets - required_reserves)

#calculates required reserves to assets ratio
RCities_data$required_reserves_to_assets <-
  with(RCities_data, required_reserves/assets)

#calculates excess liquid assets to assets ratio
RCities_data$excess_liquid_assets_to_assets <-
  with(RCities_data, excess_liquid_assets/assets)

#calculates required reserves to liquid assets ratio
RCities_data$required_reserves_to_liquid_assets <-
  with(RCities_data, required_reserves/liquid_assets)

#keep variables needed
RCities_data <- RCities_data[,c("mark_dt", "location", "required_reserves_to_assets",
                                "excess_liquid_assets_to_assets", "required_reserves_to_liquid_assets")]

#reshapes data
RCities_data <- reshape(RCities_data, timevar="location", idvar="mark_dt", direction="wide")

#required reserves to assets pooled ratio
RCities_data$required_reserves_to_assets_RC <- 
  rowMeans(RCities_data[,c("required_reserves_to_assets.Albany",       "required_reserves_to_assets.Baltimore", 
                           "required_reserves_to_assets.Boston",       "required_reserves_to_assets.Cincinnati", 
                           "required_reserves_to_assets.Cleveland",    "required_reserves_to_assets.Detroit",
                           "required_reserves_to_assets.KansasCityM",  "required_reserves_to_assets.Louisville", 
                           "required_reserves_to_assets.Milwaukee",    "required_reserves_to_assets.Minneapolis", 
                           "required_reserves_to_assets.NewOrleans",   "required_reserves_to_assets.Omaha",
                           "required_reserves_to_assets.Philadelphia", "required_reserves_to_assets.Pittsburgh", 
                           "required_reserves_to_assets.SanFrancisco", "required_reserves_to_assets.StJoseph", 
                           "required_reserves_to_assets.StPaul",       "required_reserves_to_assets.Washington")])

#excess liquid assets to assets pooled ratio
RCities_data$excess_liquid_assets_to_assets_RC <- 
  rowMeans(RCities_data[,c("excess_liquid_assets_to_assets.Albany",       "excess_liquid_assets_to_assets.Baltimore", 
                           "excess_liquid_assets_to_assets.Boston",       "excess_liquid_assets_to_assets.Cincinnati", 
                           "excess_liquid_assets_to_assets.Cleveland",    "excess_liquid_assets_to_assets.Detroit",
                           "excess_liquid_assets_to_assets.KansasCityM",  "excess_liquid_assets_to_assets.Louisville", 
                           "excess_liquid_assets_to_assets.Milwaukee",    "excess_liquid_assets_to_assets.Minneapolis", 
                           "excess_liquid_assets_to_assets.NewOrleans",   "excess_liquid_assets_to_assets.Omaha",
                           "excess_liquid_assets_to_assets.Philadelphia", "excess_liquid_assets_to_assets.Pittsburgh", 
                           "excess_liquid_assets_to_assets.SanFrancisco", "excess_liquid_assets_to_assets.StJoseph", 
                           "excess_liquid_assets_to_assets.StPaul",       "excess_liquid_assets_to_assets.Washington")])

#required reserves to liquid assets pooled ratio
RCities_data$required_reserves_to_liquid_assets_RC <- 
  rowMeans(RCities_data[,c("required_reserves_to_liquid_assets.Albany",       "required_reserves_to_liquid_assets.Baltimore", 
                           "required_reserves_to_liquid_assets.Boston",       "required_reserves_to_liquid_assets.Cincinnati", 
                           "required_reserves_to_liquid_assets.Cleveland",    "required_reserves_to_liquid_assets.Detroit",
                           "required_reserves_to_liquid_assets.KansasCityM",  "required_reserves_to_liquid_assets.Louisville", 
                           "required_reserves_to_liquid_assets.Milwaukee",    "required_reserves_to_liquid_assets.Minneapolis", 
                           "required_reserves_to_liquid_assets.NewOrleans",   "required_reserves_to_liquid_assets.Omaha",
                           "required_reserves_to_liquid_assets.Philadelphia", "required_reserves_to_liquid_assets.Pittsburgh", 
                           "required_reserves_to_liquid_assets.SanFrancisco", "required_reserves_to_liquid_assets.StJoseph", 
                           "required_reserves_to_liquid_assets.StPaul",       "required_reserves_to_liquid_assets.Washington")])

#Data for Figures 4 and 5
Figure4_5 <- merge(Figure4_5, RCities_data[, c("mark_dt", "required_reserves_to_assets_RC", 
                                               "excess_liquid_assets_to_assets_RC", 
                                               "required_reserves_to_liquid_assets_RC")])

#Section 3: Read in data for central reserve city banks and calculate ratios
####################################################################################################################

#Read in central reserve city data
CRCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
CRCities_data$mark_dt <- as.Date(CRCities_data$mark_dt, format="%m/%d/%Y")

#Multiply observations for 1911 or later by 1000 so units are consistent across dates
CRCities_data[CRCities_data$mark_dt >= "1911-01-01", 3:ncol(CRCities_data)] <- 
  CRCities_data[CRCities_data$mark_dt >= "1911-01-01", 3:ncol(CRCities_data)]*1000

#remove space from location string
CRCities_data$location <- str_replace_all(CRCities_data$location, " ", "")

#Keep central reserve cities
CRCities_data <- CRCities_data[CRCities_data$location == "Chicago" | 
                               CRCities_data$location == "NewYork" | 
                               CRCities_data$location == "StLouis",]

#replace NAs with 0s
CRCities_data[is.na(CRCities_data)] <- 0

#keep if dates in sample period
CRCities_data <- CRCities_data[CRCities_data$mark_dt >= "1894-02-28",]
CRCities_data <- CRCities_data[CRCities_data$mark_dt <= "1914-09-12" | 
                               CRCities_data$mark_dt >= "1921-02-21",]
CRCities_data <- CRCities_data[CRCities_data$mark_dt <= "1928-06-30",]

#Calculates required reserves for specified date ranges
CRCities_data$required_reserves <- NA

  #1894 to 1914
CRCities_data[CRCities_data$mark_dt>="1894-02-28" & CRCities_data$mark_dt< "1914-12-31",]$required_reserves <- 
      with(CRCities_data[CRCities_data$mark_dt>="1894-02-28" & CRCities_data$mark_dt<"1914-12-31",], 
       0.25*(inddep + US_dep + US_dispurse + 
       pmax(0, dt_national + dt_state + dt_savings + dt_redeem -
       df_redeem - df_national - df_state) - clearinghouse_exchg -
       0.5*(cash_items) - obank_bills) - Fivepct_fund)
  #1921 to 1928 St. Louis now subject to reserve city calculation
CRCities_data[CRCities_data$mark_dt>="1921-02-21" & CRCities_data$location!="StLouis",]$required_reserves <- 
  with(CRCities_data[CRCities_data$mark_dt>="1921-02-21" & CRCities_data$location!="StLouis",], 
       0.13*(Demand_deposits) + 0.03*(Time_deposits) + 
       0.13*(pmax(0, dt_national + dt_state + dt_non_national + Certified_checks_outstanding +
       Cashiers_checks_on_own_bank_outstanding - df_national - df_state - df_non_national -
       Items_with_Fed_in_process_of_collection - clearinghouse_exchg - 
       Checks_on_other_banks_in_same_place)))
  #1921 to 1928 Chicago and NYC
CRCities_data[CRCities_data$mark_dt>="1921-02-21" & CRCities_data$location=="StLouis",]$required_reserves <- 
  with(CRCities_data[CRCities_data$mark_dt>="1921-02-21" & CRCities_data$location=="StLouis",], 
       0.13*(Demand_deposits) + 0.03*(Time_deposits) + 
       0.13*(pmax(0, dt_national + dt_state + dt_non_national + Certified_checks_outstanding +
       Cashiers_checks_on_own_bank_outstanding - df_national - df_state - df_non_national -
       Items_with_Fed_in_process_of_collection - clearinghouse_exchg - 
       Checks_on_other_banks_in_same_place)))

#calculates liquid assets
CRCities_data$liquid_assets <- 
  with(CRCities_data, 
       df_redeem + df_national + DuefromFed + Checks_on_other_banks_in_same_place +
       Outside_checks_other_cash_items + cash_items + obank_bills + 
       frac_curr + specie + legaltender + US_CD + vault.cash)

#calculates excess liquid assets
CRCities_data$excess_liquid_assets <-
  with(CRCities_data, liquid_assets - required_reserves)

#calculates required reserves to assets ratio
CRCities_data$required_reserves_to_assets <-
  with(CRCities_data, required_reserves/assets)

#calculates excess liquid assets to assets ratio
CRCities_data$excess_liquid_assets_to_assets <-
  with(CRCities_data, excess_liquid_assets/assets)

#calculates required reserves to liquid assets ratio
CRCities_data$required_reserves_to_liquid_assets <-
  with(CRCities_data, required_reserves/liquid_assets)

#keep variables needed
CRCities_data <- 
  CRCities_data[,c("mark_dt", "location", "required_reserves_to_assets",
                   "excess_liquid_assets_to_assets", "required_reserves_to_liquid_assets")]

#reshapes data
CRCities_data <- reshape(CRCities_data, timevar="location", idvar="mark_dt", direction="wide")

#required reserves to assets pooled ratio
CRCities_data$required_reserves_to_assets_CRC <- 
  rowMeans(CRCities_data[,c("required_reserves_to_assets.Chicago", "required_reserves_to_assets.NewYork", 
                            "required_reserves_to_assets.StLouis")])

#excess liquid assets to assets pooled ratio
CRCities_data$excess_liquid_assets_to_assets_CRC <- 
  rowMeans(CRCities_data[,c("excess_liquid_assets_to_assets.Chicago", "excess_liquid_assets_to_assets.NewYork", 
                            "excess_liquid_assets_to_assets.StLouis")])

#required reserves to liquid assets pooled ratio
CRCities_data$required_reserves_to_liquid_assets_CRC <- 
  rowMeans(CRCities_data[,c("required_reserves_to_liquid_assets.Chicago", "required_reserves_to_liquid_assets.NewYork", 
                            "required_reserves_to_liquid_assets.StLouis")])

#Data for Figures 4 and 5
Figure4_5 <- merge(Figure4_5, CRCities_data[, c("mark_dt", "required_reserves_to_assets_CRC", 
                                                "excess_liquid_assets_to_assets_CRC", 
                                                "required_reserves_to_liquid_assets_CRC")])

#Section 4: Create and export Figures 4 and 5
####################################################################################################################

#call function used to insert gap and create sequence used as x axis in figures
Figure4_5 <- insert_gap(Figure4_5)

#specify axis breaks
xbreaks <- which(as.character(Figure4_5$mark_dt) %in% 
                   c("1894-05-04", "1895-05-07", "1896-05-07",
                     "1897-05-14", "1898-05-05", "1899-06-30",
                     "1900-06-29", "1901-07-15", "1902-07-16", 
                     "1903-06-09", "1904-06-09", "1905-05-29",
                     "1906-06-18", "1907-05-20", "1908-07-15",
                     "1909-06-23", "1910-06-30", "1911-06-07",
                     "1912-06-14", "1913-06-04", "1914-06-30",
                     "1921-06-30", "1922-06-30", "1923-06-30",
                     "1924-06-30", "1925-06-30", "1926-06-30",
                     "1927-06-30", "1928-06-30"))

#specify axis labels
xlabels=c("1894", "1895", "1896",
          "1897", "1898", "1899",
          "1900", "1901", "1902", 
          "1903", "1904", "1905",
          "1906", "1907", "1908",
          "1909", "1910", "1911",
          "1912", "1913", "1914",
          "1921", "1922", "1923",
          "1924", "1925", "1926",
          "1927", "1928")

#reshape data for use in ggplot
Figure4_5 <- melt(Figure4_5, id.vars = c("mark_dt", "xseq"))

#reorder factor level to get required reserve ratio on bottom of the plot
Figure4_5$variable <- factor(Figure4_5$variable,levels=c("excess_liquid_assets_to_assets_country",
                                                         "required_reserves_to_assets_country",
                                                         "excess_liquid_assets_to_assets_RC",
                                                         "required_reserves_to_assets_RC",
                                                         "excess_liquid_assets_to_assets_CRC",
                                                         "required_reserves_to_assets_CRC",
                                                         "required_reserves_to_liquid_assets_country",
                                                         "required_reserves_to_liquid_assets_RC",
                                                         "required_reserves_to_liquid_assets_CRC"))

#Section 4.1: Create and export Figure 4
################################################################################

#Create Figure 4.1
Figure4.1 <-
  ggplot(data=Figure4_5[Figure4_5$variable=="required_reserves_to_assets_country" |
                      Figure4_5$variable=="excess_liquid_assets_to_assets_country",],
       aes(x=xseq ,y=value, fill=variable)) +
  #bar chart
  geom_bar(stat = "identity", width=.6) +
  #format axis labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels, expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0), breaks=c(0, .05, .1, .15, .2, .25, .3, .35)) +
  coord_cartesian(ylim=c(0,.35))+
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11),
        legend.position = c(.9, .9),
        legend.title = element_blank())+
  guides(fill = guide_legend(reverse = TRUE)) +
  #insert dashed vertical line
  geom_vline(xintercept=107, linetype="dashed")+
  #specify colors and legend descriptions
  scale_fill_manual(values=c("dark gray", "black"), labels = c("Excess/Assets", "Required/Assets"))

#Export Figure 4.1
ExportPlot(Figure4.1, "output/MS16-292Figure 4-A", width=6.27, height=2.44)

#Create Figure 4.2
Figure4.2 <-
  ggplot(data=Figure4_5[Figure4_5$variable=="required_reserves_to_assets_RC" |
                          Figure4_5$variable=="excess_liquid_assets_to_assets_RC",],
         aes(x=xseq ,y=value, fill=variable)) +
  #bar chart
  geom_bar(stat = "identity", width=.6) +
  #format axis labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels, expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0), breaks=c(0, .05, .1, .15, .2, .25, .3, .35)) +
  coord_cartesian(ylim=c(0,.35))+
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11),
        legend.position = c(.9, .9),
        legend.title = element_blank())+
  guides(fill = guide_legend(reverse = TRUE)) +
  #insert dashed vertical line
  geom_vline(xintercept=107, linetype="dashed")+
  #specify colors and legend descriptions
  scale_fill_manual(values=c("dark gray", "black"), labels = c("Excess/Assets", "Required/Assets"))

#Export Figure 4.2
ExportPlot(Figure4.2, "output/MS16-292Figure 4-B", width=6.27, height=2.44)

#Create Figure 4.3
Figure4.3 <-
  ggplot(data=Figure4_5[Figure4_5$variable=="required_reserves_to_assets_CRC" |
                          Figure4_5$variable=="excess_liquid_assets_to_assets_CRC",],
         aes(x=xseq ,y=value, fill=variable)) +
  #bar chart
  geom_bar(stat = "identity", width=.6) +
  #format axis labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels, expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0), breaks=c(0, .05, .1, .15, .2, .25, .3, .35)) +
  coord_cartesian(ylim=c(0,.35))+
  #theme
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11),
        legend.position = c(.9, .9),
        legend.title = element_blank())+
  guides(fill = guide_legend(reverse = TRUE)) +
  #insert dashed vertical line
  geom_vline(xintercept=107, linetype="dashed")+
  #specify colors and legend descriptions
  scale_fill_manual(values=c("dark gray", "black"), labels = c("Excess/Assets", "Required/Assets"))

#Export Figure 4.3
ExportPlot(Figure4.3, "output/MS16-292Figure 4-C", width=6.27, height=2.44)

#Section 4.2: Create and export Figure 5
################################################################################

#Create Figure 5.1
Figure5.1 <-
  ggplot(data=Figure4_5[Figure4_5$variable=="required_reserves_to_liquid_assets_country",],
       aes(x=xseq, y=value)) +
  #bar chart
  geom_bar(stat = "identity", width=.6, fill="black") +
  coord_cartesian(ylim=c(0,.8))+
  #specify breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels, expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0), breaks=c(0, .1, .2, .3, .4, .5, .6, .7, .8)) +
  #classic theme; format axis labels
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11))+
  #add vertical dashed line to signify gap
  geom_vline(xintercept=107, linetype="dashed")

#Export Figure 5.1
ExportPlot(Figure5.1, "output/MS16-292Figure 5-A", width=6.27, height=2.44)

#Create Figure 5.2
Figure5.2 <-
  ggplot(data=Figure4_5[Figure4_5$variable=="required_reserves_to_liquid_assets_RC",],
         aes(x=xseq, y=value)) +
  #bar chart
  geom_bar(stat = "identity", width=.6, fill="black") +
  coord_cartesian(ylim=c(0,.8))+
  #specify breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels, expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0), breaks=c(0, .1, .2, .3, .4, .5, .6, .7, .8)) +
  #classic theme; format axis labels
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11))+
  #add vertical dashed line to signify gap
  geom_vline(xintercept=107, linetype="dashed")

#Export Figure 5.2
ExportPlot(Figure5.2, "output/MS16-292Figure 5-B", width=6.27, height=2.44)

#Create Figure 5.3
Figure5.3 <-
  ggplot(data=Figure4_5[Figure4_5$variable=="required_reserves_to_liquid_assets_CRC",],
         aes(x=xseq, y=value)) +
  #bar chart
  geom_bar(stat = "identity", width=.6, fill="black") +
  coord_cartesian(ylim=c(0,.8))+
  #specify breaks and labels
  scale_x_continuous(breaks=xbreaks,labels=xlabels, expand=c(0,0)) +
  scale_y_continuous(expand=c(0,0), breaks=c(0, .1, .2, .3, .4, .5, .6, .7, .8)) +
  #classic theme; format axis labels
  theme_classic()+
  theme(text=element_text(family="serif"),
        axis.title.x=element_blank(),
        axis.title.y=element_blank(),
        axis.text.x = element_text(angle =90, size = 11, vjust = 0.5),
        axis.text.y = element_text(size = 11))+
  #add vertical dashed line to signify gap
  geom_vline(xintercept=107, linetype="dashed")

#Export Figure 5.3
ExportPlot(Figure5.3, "output/MS16-292Figure 5-C", width=6.27, height=2.44)




