#"Did the Founding of the Federal Reserve Affect the Vulnerability of the Interbank System to Contagion Risk?"
#JMCB ms. #16-292
#Mark Carlson and David C. Wheelock

#Perform calculations for interbank deposit volumes
#Create and export Table 1

library(tidyverse)
library(plyr)
library(data.table)
library(RStata)

rm(list = ls())

#specify stata version and path used to call stata executable; use this format to specify path
#use chooseStataBin() function for initial setup
options("RStata.StataVersion" = 15)
options("RStata.StataPath" = "\"C:\\Program Files (x86)\\Stata15\\StataMP-64\"")

#specify directory where folder is stored
dir <- ""
setwd(dir)

#read in t test function
source("programs/R functions/ttest.R")
#read in function to transpose table
source("programs/R functions/transp.R")

#Section 1: Calculate country bank ratios included in Table 1
######################################################################################################################################################

#Read in country bank data
Country_data <- read.table("data/MS16-292EntirePeriod_states.txt", header = TRUE,
                           stringsAsFactors = FALSE)
Country_data$mark_dt <-as.Date(Country_data$mark_dt,"%m/%d/%Y")

#replaces NAs with 0
Country_data[is.na(Country_data)] <- 0

#keep if dates in sample period
Country_data <- Country_data[Country_data$mark_dt>='1894-02-28',]
Country_data <- Country_data[Country_data$mark_dt<='1914-09-12' | 
                             Country_data$mark_dt>='1921-02-21',]
Country_data <- Country_data[Country_data$mark_dt<='1928-06-30',]

#Multiply observations in 1911 or later to keep units consistent across time 
Country_data[Country_data$mark_dt >'1911-01-01',!names(Country_data) %in% c("mark_dt", "location")] <- 
Country_data[Country_data$mark_dt >'1911-01-01',!names(Country_data) %in% c("mark_dt", "location")]*1000

#keep if one of the 48 states
Country_data <- Country_data[!(Country_data$location=="Dakota" | 
                               Country_data$location=="Hawaii" | 
                               Country_data$location =="Indian Territory"),]

#calculate due from national variable
Country_data$DuefromNational <- with(Country_data, df_national + df_redeem)

#calculate due from national to assets ratio
Country_data$DuefromNational_to_assets <- with(Country_data, DuefromNational/assets)

#convert country bank data to data.table
Country_table <- as.data.table(Country_data)
#create period variable for grouping
Country_table[mark_dt<="1914-09-12", period:= "1894 to 1914"]
Country_table[mark_dt>="1921-02-21", period:= "1921 to 1928"]
#calculate mean and std dev for country bank ratios
Country_table <- 
  Country_table[, .('Country banks: Deposits due from national bank correspondents as a share of total assets (Mean)'=
                      100*mean(DuefromNational_to_assets),
                    'Country banks: Deposits due from national bank correspondents as a share of total assets (SD)'=
                      100*sd(DuefromNational_to_assets)), 
                by=period]

#transpose country table to match format of Table 1
Country_table <- transp(Country_table)

#Section 2: Calculate reserve city bank ratios included in Table 1
##############################################################################################

#Read in reserve city bank data
RCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE,
                           stringsAsFactors = FALSE)
RCities_data$mark_dt <-as.Date(RCities_data$mark_dt,"%m/%d/%Y")

#replace NAs with 0
RCities_data[is.na(RCities_data)] <- 0

#keep if dates in sample period
RCities_data <- RCities_data[RCities_data$mark_dt>='1894-02-28',]
RCities_data <- RCities_data[RCities_data$mark_dt<='1914-09-12' | 
                             RCities_data$mark_dt>='1921-02-21',]
RCities_data <- RCities_data[RCities_data$mark_dt<='1928-06-30',]

#Multiply observations in 1911 or later to keep units consistent across time 
RCities_data[RCities_data$mark_dt >'1911-01-01',!names(RCities_data) %in% c("mark_dt", "location")] <- 
RCities_data[RCities_data$mark_dt >'1911-01-01',!names(RCities_data) %in% c("mark_dt", "location")]*1000

#Keep observations if city is one of 18 reserve cities analyzed in paper
RCities_data <- 
  RCities_data[(RCities_data$location=="Albany" |        RCities_data$location=="Baltimore" |     
                RCities_data$location =="Boston" |       RCities_data$location=="Cincinnati" |   
                RCities_data$location=="Cleveland" |     RCities_data$location=="Detroit" |
                RCities_data$location=="Kansas CityM" |  RCities_data$location=="Louisville" |   
                RCities_data$location=="Milwaukee" |     RCities_data$location=="Minneapolis" |  
                RCities_data$location=="New Orleans" |   RCities_data$location=="Omaha" |
                RCities_data$location=="Philadelphia" |  RCities_data$location=="Pittsburgh" |   
                RCities_data$location=="St Joseph" |     RCities_data$location=="St Paul" |      
                RCities_data$location=="San Francisco" | RCities_data$location=="Washington"),]

#create due from national banks variable
RCities_data$DuefromNational <- with(RCities_data, df_national + df_redeem)

#create due to national banks variable
RCities_data$DuetoNational <- with(RCities_data, dt_national)

#create interbank deposit ratios used in Table 1
RCities_data$DuefromNational_to_assets <- with(RCities_data, DuefromNational/assets)
RCities_data$DuetoNational_to_assets <- with(RCities_data, DuetoNational/assets)

#convert reserve city bank data to data.table
RCities_table <- as.data.table(RCities_data)
#create period variable to use in grouping
RCities_table[mark_dt<="1914-09-12", period:= "1894 to 1914"]
RCities_table[mark_dt>="1921-02-21", period:= "1921 to 1928"]
#calculate means and std dev of interbank deposit ratios used in Table 1
RCities_table <- 
  RCities_table[, .('Reserve City Banks: Deposits due from national bank correspondents as a share of total assets (Mean)'=
                      100*mean(DuefromNational_to_assets),
                    'Reserve City Banks: Deposits due from national bank correspondents as a share of total assets (SD)'=
                      100*sd(DuefromNational_to_assets),
                    'Reserve City Banks: Deposits due to national bank correspondents as a share of total assets (Mean)'=
                      100*mean(DuetoNational_to_assets),
                    'Reserve City Banks: Deposits due to national bank correspondents as a share of total assets (SD)'=
                      100*sd(DuetoNational_to_assets)), 
                by=period]

#transpose reserve city table to match format of Table 1
RCities_table <- transp(RCities_table)

#calculate total for due to national banks and total assets in the 18 reserve cities by date
#used in ratio of central reserve city holdings as share of holdings for all cities
RCities_totals <- as.data.table(RCities_data)
RCities_totals <- RCities_totals[, .(DuetoNational.RC=sum(DuetoNational),
                                     assets.RC=sum(assets)), 
                                 by=mark_dt]

#Section 3: Calculate central reserve city bank ratios included in Table 1
#################################################################################################################

#Read in central reserve city bank data
CRCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE,
                            stringsAsFactors = FALSE)
CRCities_data$mark_dt <-as.Date(CRCities_data$mark_dt,"%m/%d/%Y")

#replace NAs with 0
CRCities_data[is.na(CRCities_data)] <- 0

#keep if dates in sample period
CRCities_data <- CRCities_data[CRCities_data$mark_dt>='1894-02-28',]
CRCities_data <- CRCities_data[CRCities_data$mark_dt<='1914-09-12' | 
                               CRCities_data$mark_dt>='1921-02-21',]
CRCities_data <- CRCities_data[CRCities_data$mark_dt<='1928-06-30',]

#Multiply observations in 1911 or later to keep units consistent across time 
CRCities_data[CRCities_data$mark_dt >'1911-01-01',!names(CRCities_data) %in% c("mark_dt", "location")] <- 
CRCities_data[CRCities_data$mark_dt >'1911-01-01',!names(CRCities_data) %in% c("mark_dt", "location")]*1000

#Keep observations if location is a central reserve city
CRCities_data <- CRCities_data[(CRCities_data$location=="New York" | 
                                CRCities_data$location=="St Louis" | 
                                CRCities_data$location=="Chicago"),]

#create due to national banks variable
CRCities_data$DuetoNational <- with(CRCities_data, dt_national)

#create due to national banks to assets ratio
CRCities_data$DuetoNational_to_assets <- with(CRCities_data, DuetoNational/assets)

#convert central reserve city banks data to data.table
CRCities_table <- as.data.table(CRCities_data)
#create period variable to use in grouping
CRCities_table[mark_dt<="1914-09-12", period:= "1894 to 1914"]
CRCities_table[mark_dt>="1921-02-21", period:= "1921 to 1928"]
#calculate means and std dev of interbank deposit ratios used in Table 1
CRCities_table <- 
  CRCities_table[, .('Central Reserve City Banks: Deposits due to national bank respondents as a share of total assets (Mean)'=
                       100*mean(DuetoNational_to_assets),
                     'Central Reserve City Banks: Deposits due to national bank respondents as a share of total assets (SD)'=
                       100*sd(DuetoNational_to_assets)), 
                 by=period]

#transpose central reserve city table to match format of Table 1
CRCities_table <- transp(CRCities_table)

#Calculate total for due to national banks and total assets in central reserve cities by date
#used in ratio of central reserve city holdings as share of holdings for all cities
CRCities_totals <- as.data.table(CRCities_data)
CRCities_totals <- CRCities_totals[, .(DuetoNational.CRC=sum(DuetoNational),
                                       assets.CRC=sum(assets)), by=mark_dt]

#Calculate share of due to national banks and total assets in central reserve cities
totals <- merge(RCities_totals, CRCities_totals, by="mark_dt")

#calculate central reserve city banks share of due to national banks
totals$DuetoNationalCRC_to_DuetoNationalCities <-
  with(totals, DuetoNational.CRC/(DuetoNational.CRC+DuetoNational.RC))

#calculate central reserve city banks share of total assets
totals$assetsCRC_to_assetsCities <-
  with(totals, assets.CRC/(assets.CRC+assets.RC))

#create period variable to use in grouping
totals[mark_dt<="1914-09-12", period:= "1894 to 1914"]
totals[mark_dt>="1921-02-21", period:= "1921 to 1928"]

#calculate mean and std dev of interbank deposit ratios used in Table 1
totals_table <- 
  totals[, .('Central reserve city banks share of deposits due to national banks in central reserve cities and 18 reserve cities (Mean)'=
               100*mean(DuetoNationalCRC_to_DuetoNationalCities),
             'Central reserve city banks share of deposits due to national banks in central reserve cities and 18 reserve cities (SD)'=
               100*sd(DuetoNationalCRC_to_DuetoNationalCities),
             'Central reserve city banks share of total assets in central reserve cities and 18 reserve cities (Mean)'=
               100*mean(assetsCRC_to_assetsCities),
             'Central reserve city banks share of total assets in central reserve cities and 18 reserve cities (SD)'=
               100*sd(assetsCRC_to_assetsCities)), by=period]

#transpose table to match format of Table 1
totals_table <- transp(totals_table)

#Combine results into single data frame for Table 1
Table1 <- rbind(Country_table, RCities_table, CRCities_table, totals_table)

#Section 4: Generate t statistics and import them into Table 1
#############################################################################################################################################

#Initialize t statistic variable for Table 1
Table1$'T-statistic for difference' <- NA


####################### Section 4.1: Country banks ###################################
#create period dummy variable for country banks
Country_data$period <- 0
Country_data[Country_data$mark_dt >="1921-02-21",]$period <- 1

#stata code to run panel regression for country banks
Country_test <- 
"
encode location, generate(location_encode)

xtset mark_dt location_encode
describe

reg DuefromNational_to_assets i.location_encode i.period, robust cluster(location_encode)
"

#run the above Stata code
stata(Country_test, data.in = Country_data)

#Plug t statistic from period variable regression results into Table 1
Table1[row.names(Table1) == 
      "Country banks: Deposits due from national bank correspondents as a share of total assets (Mean)", 
      "T-statistic for difference"] <- "-21.8***"

####################### Section 4.2: Reserve City banks ###################################
#create period dummy variable for reserve city banks
RCities_data$period <- 0
RCities_data[RCities_data$mark_dt >="1921-02-21",]$period <- 1

#Stata code to run panel regressions for reserve city banks
RCities_test <- 
"
encode location, generate(location_encode)

xtset mark_dt location_encode
reg DuefromNational_to_assets i.location_encode i.period, robust cluster(location_encode)
reg DuetoNational_to_assets i.location_encode i.period, robust cluster(location_encode)
"

#run the above Stata code
stata(RCities_test, data.in = RCities_data)

#Plug t statistic from period variable regression results into Table 1
Table1[row.names(Table1) == 
       "Reserve City Banks: Deposits due from national bank correspondents as a share of total assets (Mean)", 
       "T-statistic for difference"] <- "-12.5***"

Table1[row.names(Table1) == 
       "Reserve City Banks: Deposits due to national bank correspondents as a share of total assets (Mean)", 
       "T-statistic for difference"] <- "-5.6***"

####################### Section 4.3: Central Reserve City banks #############################
#create period dummy variables for central reserve city banks
CRCities_data$period <- 0
CRCities_data[CRCities_data$mark_dt >="1921-02-21",]$period <- 1

#Stata code to run panel regression for central reserve city banks
CRCities_test <- 
"
encode location, generate(location_encode)

xtset mark_dt location_encode
reg DuetoNational_to_assets i.location_encode i.period, robust cluster(location_encode)

"

#run the above Stata code
stata(CRCities_test, data.in = CRCities_data)

#Plug t statistic from period variable regression results into Table 1
Table1[row.names(Table1) == 
       "Central Reserve City Banks: Deposits due to national bank respondents as a share of total assets (Mean)", 
       "T-statistic for difference"] <- "-23.7***"

################## Section 4.4: Central reserve city banks as share of cities ##########################
Table1["Central reserve city banks share of deposits due to national banks in central reserve cities and 18 reserve cities (Mean)", 
       "T-statistic for difference"] <- 
  ttest(totals[totals$mark_dt>="1921-02-21",]$DuetoNationalCRC_to_DuetoNationalCities,
  totals[totals$mark_dt<="1914-09-12",]$DuetoNationalCRC_to_DuetoNationalCities)

Table1["Central reserve city banks share of total assets in central reserve cities and 18 reserve cities (Mean)", 
      "T-statistic for difference"] <- 
  ttest(totals[totals$mark_dt>="1921-02-21",]$assetsCRC_to_assetsCities,
        totals[totals$mark_dt<="1914-09-12",]$assetsCRC_to_assetsCities)

#Export Table 1 to .csv
write.csv(Table1, file = "output/MS16-292Table 1.csv")