#"Did the Founding of the Federal Reserve Affect the Vulnerability of the Interbank System to Contagion Risk?"
#JMCB ms. #16-292
#Mark Carlson and David C. Wheelock

#Calculate interbank deposit flows in normal and panic periods for different groups of banks.
#Creates and exports Table 3.

library(tidyverse)
library(plyr)
library(data.table)

rm(list = ls())

#specify directory where folder is stored
dir <- ""
setwd(dir)

#Section 1: Country banks; due from national scaled by own assets
###################################################################################################################

#Read in country bank data
Country_data <- read.table("data/MS16-292EntirePeriod_states.txt", header = TRUE)
Country_data$mark_dt <-as.Date(Country_data$mark_dt,"%m/%d/%Y")

#replace NA with 0
Country_data[is.na(Country_data)] <- 0

#Keep only 48 states
Country_data <- Country_data[!(Country_data$location=="Dakota" | 
                               Country_data$location=="Hawaii" | 
                               Country_data$location =="Indian Territory"),]

#Subset on dates
Country_data <- Country_data[Country_data$mark_dt %in% 
                             as.Date(c('1893-05-04', '1893-10-03', '1893-12-19',
                                       '1894-05-04', '1894-10-02', '1894-12-19',
                                       '1895-05-07', '1895-09-28', '1895-12-13',
                                       '1896-05-07', '1896-10-06', '1896-12-17',
                                       '1897-05-14', '1897-10-05', '1897-12-15',
                                       '1898-05-05', '1898-09-20', '1898-12-01',
                                       '1899-04-05', '1899-09-07', '1899-12-02',
                                       '1900-04-26', '1900-09-05', '1900-12-13',
                                       '1901-04-24', '1901-09-30', '1901-12-10',
                                       '1902-04-30', '1902-09-15', '1902-11-25',
                                       '1903-04-09', '1903-09-09', '1903-11-17',
                                       '1904-03-28', '1904-09-06', '1904-11-10',
                                       '1905-03-14', '1905-08-25', '1905-11-09',
                                       '1906-04-06', '1906-09-04', '1906-11-12',
                                       '1907-03-22', '1907-08-22', '1907-12-03')),]

#Create date classifications used to calculate changes in interbank deposits
Country_data$year <- with(Country_data, year(mark_dt))
Country_data$month <- NA
Country_data[month(Country_data$mark_dt) == 3  | 
             month(Country_data$mark_dt) == 4  | 
             month(Country_data$mark_dt) == 5, ]$month <- "May"
Country_data[month(Country_data$mark_dt) == 8  | 
             month(Country_data$mark_dt) == 9  | 
             month(Country_data$mark_dt) == 10,]$month <- "Sept"
Country_data[month(Country_data$mark_dt) == 11 | 
             month(Country_data$mark_dt) == 12,]$month <- "Dec"

#Calculate due from national banks
Country_data$DuefromNational <- with(Country_data, df_national + df_redeem)

#Keep needed variables
Country_data <- Country_data[,c("year", "month", "location", "DuefromNational", "assets")]

#reshape data
Country_data <- reshape(Country_data, direction="wide", 
                        timevar="month", idvar=c("year", "location"))

#calculate change from May to September                                                    
Country_data$DuefromNational.May_Sept <- 
  with(Country_data, 100*(DuefromNational.Sept-DuefromNational.May)/assets.May)

#Calculate changes from September to December
Country_data$DuefromNational.Sept_Dec <- 
  with(Country_data, 100*(DuefromNational.Dec-DuefromNational.Sept)/assets.Sept)

#Create state groupings
Country_data$type <- NA
Country_data[Country_data$location %in% 
    c('Connecticut',    'Delaware',      'Maine',
      'Maryland',       'Massachusetts', 'New Hampshire',
      'New Jersey',     'New York',      'Pennsylvania',
      'Rhode Island',   'Vermont',       'Virginia'),]$type <- "New England and Mid-Atlantic"

Country_data[Country_data$location %in% 
    c('Illinois',       'Indiana',       'Kentucky',
      'Michigan',       'Missouri',      'Ohio',
      'West Virginia',  'Wisconsin'),]$type <- "Upper Midwest"

Country_data[Country_data$location %in% 
    c('Alabama',        'Arkansas',      'Florida',
      'Georgia',        'Louisiana',     'Mississippi',
      'North Carolina', 'Oklahoma',      'South Carolina',
      'Tennessee',      'Texas'),]$type <- "Southern"

Country_data[Country_data$location %in% 
    c('Colorado',       'Iowa',          'Kansas',
      'Minnesota',      'Nebraska',      'North Dakota',
      'South Dakota',   'Wyoming'),]$type <- "Plains"

Country_data[Country_data$location %in% 
    c('Arizona',        'California',    'Idaho',
      'Montana',        'Nevada',        'New Mexico',
      'Oregon',         'Utah',          'Washington'),]$type <- "Western"

#create time period variable
Country_data$time <- NA
Country_data[Country_data$year==1893,]$time <- "1893"
Country_data[Country_data$year>=1894 & Country_data$year<=1906,]$time <- "1894-1906"
Country_data[Country_data$year==1907,]$time <- "1907"

#convert country banks data to data.table
Country_data <- data.table(Country_data[,
                  c("year", "location", "type", "time", 
                    "DuefromNational.Sept", "DuefromNational.May", 
                    "DuefromNational.Dec", "assets.May", "assets.Sept", 
                    "DuefromNational.May_Sept", "DuefromNational.Sept_Dec")])

#calculate averages across all states for each period
#average over states
Country_data_all <- 
  Country_data[, .(mean.DuefromNational.May_Sept=mean(DuefromNational.May_Sept), 
                   mean.DuefromNational.Sept_Dec=mean(DuefromNational.Sept_Dec)), 
               by=c("year", "time")]

#average over years
Country_data_all <- 
  Country_data_all[, .(mean.DuefromNational.May_Sept=mean(mean.DuefromNational.May_Sept), 
                       mean.DuefromNational.Sept_Dec=mean(mean.DuefromNational.Sept_Dec)), 
                   by=time]

#create variable with group type
Country_data_all$type <- "Country"

Country_data_all <- Country_data_all[,c("time", "type", 
                                        "mean.DuefromNational.May_Sept", 
                                        "mean.DuefromNational.Sept_Dec")]

#Calculate average across regions and period
#average over states
Country_data_region <- Country_data[, .(mean.DuefromNational.May_Sept=mean(DuefromNational.May_Sept), 
                                        mean.DuefromNational.Sept_Dec=mean(DuefromNational.Sept_Dec)), 
                                    by=c("year", "time", "type")]

#average over years
Country_data_region <- 
  Country_data_region[, .(mean.DuefromNational.May_Sept=mean(mean.DuefromNational.May_Sept), 
                          mean.DuefromNational.Sept_Dec=mean(mean.DuefromNational.Sept_Dec)), 
                      by=c("time", "type")]

#Combine averages for all country banks and regions
Country_data_averages <- rbind(Country_data_all, Country_data_region)

#reshape data
Country_data_averages <- reshape(Country_data_averages, direction="wide", 
                                 timevar="time", idvar=c("type"))

#keep variables reported in Table 3
Country_data_averages <- 
  Country_data_averages[,c("type", "mean.DuefromNational.May_Sept.1894-1906", "mean.DuefromNational.May_Sept.1893",
                           "mean.DuefromNational.Sept_Dec.1894-1906", "mean.DuefromNational.Sept_Dec.1907")]

#rename variables
setnames(Country_data_averages, 
         old=c("type", "mean.DuefromNational.May_Sept.1894-1906", "mean.DuefromNational.May_Sept.1893",
                       "mean.DuefromNational.Sept_Dec.1894-1906", "mean.DuefromNational.Sept_Dec.1907"),
         new=c("type", "May_Sept.1894-1906", "May_Sept.1893", "Sept_Dec.1894-1906", "Sept_Dec.1907"))

#reorder rows
Country_data_averages <- 
  Country_data_averages[match(c("Country", "New England and Mid-Atlantic", 
                                "Upper Midwest", "Southern", "Plains", "Western"), 
                              Country_data_averages$type),]

#Section 2: Reserve city and central reserve city banks; due to national scaled by own assets
###############################################################################################################

#Read in reserve city data
RCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE)
RCities_data$mark_dt <-as.Date(RCities_data$mark_dt,"%m/%d/%Y")

#replace NA with 0
RCities_data[is.na(RCities_data)] <- 0

#keep if one of 18 reserve cities or central reserve city
RCities_data <- RCities_data[!(RCities_data$location=="Indianapolis"),]

#Subset on data
RCities_data <- RCities_data[RCities_data$mark_dt %in% 
                  as.Date(c('1893-05-04', '1893-10-03', '1893-12-19',
                            '1894-05-04', '1894-10-02', '1894-12-19',
                            '1895-05-07', '1895-09-28', '1895-12-13',
                            '1896-05-07', '1896-10-06', '1896-12-17',
                            '1897-05-14', '1897-10-05', '1897-12-15',
                            '1898-05-05', '1898-09-20', '1898-12-01',
                            '1899-04-05', '1899-09-07', '1899-12-02',
                            '1900-04-26', '1900-09-05', '1900-12-13',
                            '1901-04-24', '1901-09-30', '1901-12-10',
                            '1902-04-30', '1902-09-15', '1902-11-25',
                            '1903-04-09', '1903-09-09', '1903-11-17',
                            '1904-03-28', '1904-09-06', '1904-11-10',
                            '1905-03-14', '1905-08-25', '1905-11-09',
                            '1906-04-06', '1906-09-04', '1906-11-12',
                            '1907-03-22', '1907-08-22', '1907-12-03')),]

#Create date classifications used to calculate changes in interbank deposits
RCities_data$year <- with(RCities_data, year(mark_dt))
RCities_data$month <- NA
RCities_data[month(RCities_data$mark_dt) == 3  | 
             month(RCities_data$mark_dt) == 4  | 
             month(RCities_data$mark_dt) == 5,]$month <- "May"

RCities_data[month(RCities_data$mark_dt) == 8  | 
             month(RCities_data$mark_dt) == 9  | 
             month(RCities_data$mark_dt) == 10,]$month <- "Sept"

RCities_data[month(RCities_data$mark_dt) == 11 | 
             month(RCities_data$mark_dt) == 12,]$month <- "Dec"

#Create due from national and due to national variables
RCities_data$DuefromNational <- with(RCities_data, df_national + df_redeem)
RCities_data$DuetoNational <- with(RCities_data, dt_national)

#Keep needed variables
RCities_data <- RCities_data[,c("year", "month", "location", 
                                "DuefromNational", "DuetoNational", "assets")]

#reshape data
RCities_data <- reshape(RCities_data, direction="wide", 
                        timevar="month", idvar=c("year", "location"))

#calculate changes
RCities_data$DuetoNational.May_Sept <- with(RCities_data, 100*(DuetoNational.Sept-DuetoNational.May)/assets.May)
RCities_data$DuetoNational.Sept_Dec <- with(RCities_data, 100*(DuetoNational.Dec-DuetoNational.Sept)/assets.Sept)

#create time period variable
RCities_data$time <- NA
RCities_data[RCities_data$year==1893,]$time <- "1893"
RCities_data[RCities_data$year>=1894 & RCities_data$year<=1906,]$time <- "1894-1906"
RCities_data[RCities_data$year==1907,]$time <- "1907"

#create type variable
RCities_data$type <- NA
RCities_data[RCities_data$location %in% 
               c('Albany',       'Baltimore',   'Boston',
                 'Cincinnati',   'Cleveland',   'Detroit',
                 'Kansas CityM', 'Louisville',  'Milwaukee',
                 'Minneapolis',  'New Orleans', 'Omaha',
                 'Philadelphia', 'Pittsburgh',  'San Francisco',
                 'St Joseph',    'St Louis',    'St Paul',
                 'Washington'),]$type <- "RC"

RCities_data[RCities_data$location %in% 
               c('Chicago', 'New York', 'St Louis'),]$type <- "CRC"

#convert to data.table
RCities_data <- data.table(RCities_data)

#Calculate averages over cities
RCities_data_all <- 
  RCities_data[, .(mean.DuetoNational.May_Sept=mean(DuetoNational.May_Sept), 
                   mean.DuetoNational.Sept_Dec=mean(DuetoNational.Sept_Dec)), 
               by=c("year", "time", "type")]

#calculate averages over years
RCities_data_all  <- 
  RCities_data_all[, .(mean.DuetoNational.May_Sept=mean(mean.DuetoNational.May_Sept), 
                       mean.DuetoNational.Sept_Dec=mean(mean.DuetoNational.Sept_Dec)), 
                   by=c("time", "type")]

#reshape data
RCities_data_all <- reshape(RCities_data_all, direction="wide", 
                            timevar="time", idvar=c("type"))

#keep variables needed for Table 3
RCities_data_all <- 
  RCities_data_all[,c("type", "mean.DuetoNational.May_Sept.1894-1906", "mean.DuetoNational.May_Sept.1893",
                             "mean.DuetoNational.Sept_Dec.1894-1906", "mean.DuetoNational.Sept_Dec.1907")]

#rename variables
setnames(RCities_data_all, 
         old=c("type", "mean.DuetoNational.May_Sept.1894-1906", "mean.DuetoNational.May_Sept.1893",
                       "mean.DuetoNational.Sept_Dec.1894-1906", "mean.DuetoNational.Sept_Dec.1907"),
         new=c("type", "May_Sept.1894-1906", "May_Sept.1893", 
               "Sept_Dec.1894-1906", "Sept_Dec.1907"))

#Section 3: Country banks; due from national scaled by assets in reserve and central reserve cities
#################################################################################################################

#aggregates due from national for country banks by year
DuefromNational_Country <- 
  Country_data[, .(DuefromNational.Sept=sum(DuefromNational.Sept), DuefromNational.May=sum(DuefromNational.May),
                  DuefromNational.Dec=sum(DuefromNational.Dec)), 
                  by=c("year", "time")]

#create type variable
DuefromNational_Country$type <- "Country_agg"

#keep only needed variables
DuefromNational_Country <- 
  DuefromNational_Country[,c("year", "time", "type", "DuefromNational.Sept", "DuefromNational.May", 
                          "DuefromNational.Dec")]

#aggregates assets in reserve and central reserve cities
assets_RCities <- 
  RCities_data[, .(assets.May=sum(assets.May), assets.Sept=sum(assets.Sept)), 
 by=c("year", "time", "type")]

#reshapes data
assets_RCities <- 
  reshape(assets_RCities, direction="wide", timevar=c("type"), idvar=c("time", "year"))

#combine due from national for country banks with total assets from city banks
DuefromNational_Country <- 
  cbind(DuefromNational_Country, assets_RCities[
    ,c("assets.May.RC", "assets.Sept.RC", 
       "assets.May.CRC", "assets.Sept.CRC")])


#calculate scaled changes
DuefromNational_Country$DuefromNational.May_Sept <- 
  with(DuefromNational_Country, 100*(DuefromNational.Sept-DuefromNational.May)/(assets.May.RC+assets.May.CRC))

DuefromNational_Country$DuefromNational.Sept_Dec <- 
  with(DuefromNational_Country, 100*(DuefromNational.Dec-DuefromNational.Sept)/(assets.Sept.RC + assets.Sept.CRC))

#calculate average of changes across years
DuefromNational_Country <- 
  DuefromNational_Country[, .(DuefromNational.May_Sept=mean(DuefromNational.May_Sept), 
                              DuefromNational.Sept_Dec=mean(DuefromNational.Sept_Dec)), 
                              by=c("time", "type")]

#reshape data
DuefromNational_Country <- reshape(DuefromNational_Country, direction="wide", timevar="time", idvar=c("type"))

#keep variables included in Table 3
DuefromNational_Country <- 
  DuefromNational_Country[,c("type", "DuefromNational.May_Sept.1894-1906", "DuefromNational.May_Sept.1893",
                                     "DuefromNational.Sept_Dec.1894-1906", "DuefromNational.Sept_Dec.1907")]

#change column names
setnames(DuefromNational_Country, 
         old=c("type", "DuefromNational.May_Sept.1894-1906", "DuefromNational.May_Sept.1893",
                       "DuefromNational.Sept_Dec.1894-1906", "DuefromNational.Sept_Dec.1907"),
         new=c("type", "May_Sept.1894-1906", "May_Sept.1893", "Sept_Dec.1894-1906", "Sept_Dec.1907"))


#combine sub-tables to form complete Table 3
Table3 <- rbind(Country_data_averages, DuefromNational_Country, RCities_data_all)

#rename type variable to correspond with Table 3
Table3[Table3$type=="Country", "type"] <- 
  "All country banks, due from national banks scaled by own total assets"

Table3[Table3$type=="New England and Mid-Atlantic", "type"] <- 
  "New England & Mid-Atlantic banks, due from national banks scaled by own total assets"

Table3[Table3$type=="Upper Midwest", "type"] <-
  "Upper Midwest banks, due from national banks scaled by own total assets"

Table3[Table3$type=="Southern", "type"] <-
  "Southern banks, due from national banks scaled by own total assets"

Table3[Table3$type=="Plains", "type"] <-
  "Plains banks, due from national banks scaled by own total assets"

Table3[Table3$type=="Western", "type"] <-
  "Western banks, due from national banks scaled by own total assets"

Table3[Table3$type=="Country_agg", "type"] <-
  "All country banks, due from national banks scaled by total assets of banks in reserve cities and central reserve cities"

Table3[Table3$type=="RC", "type"] <-
  "Reserve city banks, due from national banks scaled by total assets of banks in central reserve cities"

Table3[Table3$type=="CRC", "type"] <-
  "Reserve city banks, due to national banks scaled by own total assets"

#Export Table 3 to .csv
write.csv(Table3, file = "output/MS16-292Table 3.csv", row.names = FALSE)