#"Did the Founding of the Federal Reserve Affect the Vulnerability of the Interbank System to Contagion Risk?"
#JMCB ms. #16-292
#Mark Carlson and David C. Wheelock

#Perform calculations for liquidity at national banks
#Create and export Table 5


library(tidyverse)
library(plyr)
library(data.table)
library(RStata)

rm(list = ls())

#specify stata version and path used to call stata executable; use this format to specify path
#use chooseStataBin() function for initial setup
options("RStata.StataVersion" = 15)
options("RStata.StataPath" = "\"C:\\Program Files (x86)\\Stata15\\StataMP-64\"")

#specify directory where folder is stored
dir <- ""
setwd(dir)

#read in function to transpose table
source("programs/R functions/transp.R")

#Section 1: Calculate liquidity ratios for country banks
############################################################################################################

#Read in country bank data
Country_data <- read.table("data/MS16-292EntirePeriod_states.txt", header = TRUE,
                           stringsAsFactors = FALSE)
Country_data$mark_dt <- as.Date(Country_data$mark_dt, format="%m/%d/%Y")

#entries change from dollars to thousands of dollars in 1911; make units consistent
Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)] <- 
Country_data[Country_data$mark_dt >= "1911-01-01",3:ncol(Country_data)]*1000

#remove space from location string
Country_data$location <- str_replace_all(Country_data$location, " ", "")

#keep only 48 states
Country_data <- Country_data[Country_data$location != "Dakota" & 
                             Country_data$location != "Hawaii" & 
                             Country_data$location != "IndianTerritory",]

#Replace NAs with 0s
Country_data[is.na(Country_data)] <- 0

#keep if dates in sample period
Country_data <- Country_data[Country_data$mark_dt >= "1894-02-28",]
Country_data <- Country_data[Country_data$mark_dt <= "1914-09-12" | 
                             Country_data$mark_dt >= "1921-02-21",]
Country_data <- Country_data[Country_data$mark_dt <= "1928-06-30",]

#create required reserves variable
Country_data$required_reserves <- NA

#Calculates required reserves for specified date ranges
Country_data[Country_data$mark_dt>="1894-02-28" & Country_data$mark_dt<"1914-12-31",]$required_reserves <- 
  with(Country_data[Country_data$mark_dt>="1894-02-28" & Country_data$mark_dt<"1914-12-31",], 
       0.15*(inddep + US_dep + US_dispurse + 
       pmax(0,dt_national+dt_state+dt_savings+dt_redeem-
       df_redeem-df_national-df_state)-clearinghouse_exchg-
       0.5*(cash_items)-obank_bills)-Fivepct_fund)

Country_data[Country_data$mark_dt>="1921-02-21",]$required_reserves <- 
  with(Country_data[Country_data$mark_dt>="1921-02-21",], 
       0.07*(Demand_deposits) + 0.03*(Time_deposits) + 
       0.07*(pmax(0, dt_national + dt_state + dt_non_national + Certified_checks_outstanding +
       Cashiers_checks_on_own_bank_outstanding - df_national - df_state - df_non_national -
       Items_with_Fed_in_process_of_collection - clearinghouse_exchg - 
       Checks_on_other_banks_in_same_place)))

#calculates liquid assets
Country_data$liquid_assets <- 
  with(Country_data, 
       df_redeem+df_national+DuefromFed+Checks_on_other_banks_in_same_place+
       Outside_checks_other_cash_items+cash_items+US_CD+
       obank_bills+frac_curr+specie+legaltender+vault.cash)

#calculates excess liquid assets
Country_data$excess_liquid_assets <-
  with(Country_data, liquid_assets - required_reserves)

#calculates cash component of legal reserves pre-1914
Country_data$legal_reserves_cash <-
  with(Country_data, specie+legaltender+frac_curr+US_CD)

#calculates total legal reserves
Country_data$legal_reserves_total <-
  with(Country_data, legal_reserves_cash+df_redeem)

Country_data[Country_data$mark_dt>="1921-02-21",]$legal_reserves_total <- 
Country_data[Country_data$mark_dt>="1921-02-21",]$DuefromFed

#calculates excess legal reserves
Country_data$excess_legal_reserves <-
  with(Country_data, 
       legal_reserves_total - required_reserves)

#calculates ratios over total assets
Country_data$liquid_assets_to_assets <-
  with(Country_data, liquid_assets/assets)

Country_data$required_reserves_to_assets <-
  with(Country_data, required_reserves/assets)

Country_data$required_reserves_to_liquid_assets <-
  with(Country_data, required_reserves/liquid_assets)

Country_data$excess_liquid_assets_to_assets <-
  with(Country_data, excess_liquid_assets/assets)

Country_data$excess_reserves_to_total_reserves <-
  with(Country_data, excess_legal_reserves/legal_reserves_total)

#create period variable to use in grouping
Country_data$period <- "1894-1914"
Country_data[Country_data$mark_dt>="1921-02-21", "period"] <- "1921-1928"

#convert country bank data to data.table
Country_table <- as.data.table(Country_data)

#take mean and standard deviation of country bank ratios
Country_table <- 
  Country_table[, 
    .('Liquid Assets as a Share of Total Assets: Country banks (Mean)'=100*mean(liquid_assets_to_assets),
      'Liquid Assets as a Share of Total Assets: Country banks (SD)'=100*sd(liquid_assets_to_assets),
      'Required Reserves as a Share of Total Assets: Country banks (Mean)'=100*mean(required_reserves_to_assets),
      'Required Reserves as a Share of Total Assets: Country banks (SD)'=100*sd(required_reserves_to_assets),
      'Required Reserves as a Share of Liquid Assets: Country banks (Mean)'=100*mean(required_reserves_to_liquid_assets),
      'Required Reserves as a Share of Liquid Assets: Country banks (SD)'=100*sd(required_reserves_to_liquid_assets),
      'Excess Liquid Assets as a Share of Total Assets: Country banks (Mean)'=100*mean(excess_liquid_assets_to_assets),
      'Excess Liquid Assets as a Share of Total Assets: Country banks (SD)'=100*sd(excess_liquid_assets_to_assets),
      'Excess Reserves as a Share of Total Reserves: Country banks (Mean)'=100*mean(excess_reserves_to_total_reserves),
      'Excess Reserves as a Share of Total Reserves: Country banks (SD)'=100*sd(excess_reserves_to_total_reserves)), 
    by=period]

#transpose country table to match format of Table 5
Country_table <- transp(Country_table)

#Section 2: Calculate liquidity ratios for reserve city banks
############################################################################################################

#read in reserve city bank data
RCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE,
                           stringsAsFactors = FALSE)
RCities_data$mark_dt <- as.Date(RCities_data$mark_dt, format="%m/%d/%Y")

#entries change from dollars to thousands of dollars in 1911; make units consistent
RCities_data[RCities_data$mark_dt >= "1911-01-01",3:ncol(RCities_data)] <- 
RCities_data[RCities_data$mark_dt >= "1911-01-01",3:ncol(RCities_data)]*1000

#remove space from location string
RCities_data$location <- str_replace_all(RCities_data$location, " ", "")

#Keep 18 reserve cities used in analysis
RCities_data <- RCities_data[RCities_data$location != "Indianapolis" & 
                             RCities_data$location != "Chicago" & 
                             RCities_data$location != "NewYork",]

#replace NAs with 0s
RCities_data[is.na(RCities_data)] <- 0

#keep if dates in sample period
RCities_data <- RCities_data[RCities_data$mark_dt >= "1894-02-28",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1914-09-12" | 
                             RCities_data$mark_dt >= "1921-02-21",]
RCities_data <- RCities_data[RCities_data$mark_dt <= "1928-06-30",]

#create required reserves variable
RCities_data$required_reserves <- NA

#Calculates required reserves for specified date ranges
RCities_data[RCities_data$mark_dt>="1894-02-28" & RCities_data$mark_dt<"1914-12-31",]$required_reserves <- 
  with(RCities_data[RCities_data$mark_dt>="1894-02-28" & RCities_data$mark_dt<"1914-12-31",], 
       0.25*(inddep + US_dep + US_dispurse + 
       pmax(0,dt_national+dt_state+dt_savings+dt_redeem-
       df_redeem-df_national-df_state)-clearinghouse_exchg-
       0.5*(cash_items)-obank_bills)-Fivepct_fund)

RCities_data[RCities_data$mark_dt>="1921-02-21",]$required_reserves <- 
  with(RCities_data[RCities_data$mark_dt>="1921-02-21",], 
       0.1*(Demand_deposits) + 0.03*(Time_deposits) + 
       0.1*(pmax(0, dt_national + dt_state + dt_non_national + Certified_checks_outstanding +
       Cashiers_checks_on_own_bank_outstanding - df_national - df_state - df_non_national -
       Items_with_Fed_in_process_of_collection - clearinghouse_exchg - 
       Checks_on_other_banks_in_same_place)))

#calculates liquid assets
RCities_data$liquid_assets <- 
  with(RCities_data, 
       df_redeem+df_national+DuefromFed+Checks_on_other_banks_in_same_place+
       Outside_checks_other_cash_items+cash_items+US_CD+
       obank_bills+frac_curr+specie+legaltender+vault.cash)

#calculates excess liquid assets
RCities_data$excess_liquid_assets <-
  with(RCities_data, liquid_assets - required_reserves)

#calculates cash component of legal reserves pre-1914
RCities_data$legal_reserves_cash <-
  with(RCities_data, specie+legaltender+frac_curr+US_CD)

#calculates total legal reserves pre-1914
RCities_data$legal_reserves_total <-
  with(RCities_data, legal_reserves_cash+df_redeem)

RCities_data[RCities_data$mark_dt>="1921-02-21",]$legal_reserves_total <- 
RCities_data[RCities_data$mark_dt>="1921-02-21",]$DuefromFed

#calculates excess legal reserves
RCities_data$excess_legal_reserves <-
  with(RCities_data, 
       legal_reserves_total - required_reserves)

#calculates ratios over total assets
RCities_data$liquid_assets_to_assets <-
  with(RCities_data, liquid_assets/assets)

RCities_data$required_reserves_to_assets <-
  with(RCities_data, required_reserves/assets)

RCities_data$excess_liquid_assets_to_assets <-
  with(RCities_data, excess_liquid_assets/assets)

RCities_data$required_reserves_to_liquid_assets <-
  with(RCities_data, required_reserves/liquid_assets)

RCities_data$excess_reserves_to_total_reserves <-
  with(RCities_data, excess_legal_reserves/legal_reserves_total)

#create period variable to use in grouping
RCities_data$period <- "1894-1914"
RCities_data[RCities_data$mark_dt>="1921-02-21", "period"] <- "1921-1928"

#convert reserve city data to data.table
RCities_table <- as.data.table(RCities_data)

#take mean and standard deviation of reserve city bank ratios
RCities_table <- 
  RCities_table[, 
    .('Liquid Assets as a Share of Total Assets: Reserve city banks (Mean)'=100*mean(liquid_assets_to_assets),
      'Liquid Assets as a Share of Total Assets: Reserve city banks (SD)'=100*sd(liquid_assets_to_assets),
      'Required Reserves as a Share of Total Assets: Reserve city banks (Mean)'=100*mean(required_reserves_to_assets),
      'Required Reserves as a Share of Total Assets: Reserve city banks (SD)'=100*sd(required_reserves_to_assets),
      'Required Reserves as a Share of Liquid Assets: Reserve city banks (Mean)'=100*mean(required_reserves_to_liquid_assets),
      'Required Reserves as a Share of Liquid Assets: Reserve city banks (SD)'=100*sd(required_reserves_to_liquid_assets),
      'Excess Liquid Assets as a Share of Total Assets: Reserve city banks (Mean)'=100*mean(excess_liquid_assets_to_assets),
      'Excess Liquid Assets as a Share of Total Assets: Reserve city banks (SD)'=100*sd(excess_liquid_assets_to_assets),
      'Excess Reserves as a Share of Total Reserves: Reserve city banks (Mean)'=100*mean(excess_reserves_to_total_reserves),
      'Excess Reserves as a Share of Total Reserves: Reserve city banks (SD)'=100*sd(excess_reserves_to_total_reserves)),
    by=period]

#transpose reserve city table to match format of Table 5
RCities_table <- transp(RCities_table)

#Section 3: Calculate liquidity ratios for central reserve city banks
############################################################################################################

#Read in central reserve city data
CRCities_data <- read.table("data/MS16-292RCbanks_entireperiod_used.txt", header = TRUE,
                            stringsAsFactors = FALSE)
CRCities_data$mark_dt <- as.Date(CRCities_data$mark_dt, format="%m/%d/%Y")

#entries change from dollars to thousands of dollars in 1911; make units consistent
CRCities_data[CRCities_data$mark_dt >= "1911-01-01",3:ncol(CRCities_data)] <- 
CRCities_data[CRCities_data$mark_dt >= "1911-01-01",3:ncol(CRCities_data)]*1000

#remove space from location string
CRCities_data$location <- str_replace_all(CRCities_data$location, " ", "")

#Keep central reserve cities
CRCities_data <- CRCities_data[CRCities_data$location == "Chicago" | 
                               CRCities_data$location == "NewYork" | 
                               CRCities_data$location == "StLouis",]

#replace NAs with 0s
CRCities_data[is.na(CRCities_data)] <- 0

#keep if dates in sample period
CRCities_data <- CRCities_data[CRCities_data$mark_dt >= "1894-02-28",]
CRCities_data <- CRCities_data[CRCities_data$mark_dt <= "1914-09-12" | 
                               CRCities_data$mark_dt >= "1921-02-21",]
CRCities_data <- CRCities_data[CRCities_data$mark_dt <= "1928-06-30",]

#create required reserves variable
CRCities_data$required_reserves <- NA

#Calculates required reserves for specified date ranges
CRCities_data[CRCities_data$mark_dt>="1894-02-28" & CRCities_data$mark_dt<"1914-12-31",]$required_reserves <- 
  with(CRCities_data[CRCities_data$mark_dt>="1894-02-28" & CRCities_data$mark_dt<"1914-12-31",], 
       0.25*(inddep + US_dep + US_dispurse + 
       pmax(0,dt_national+dt_state+dt_savings+dt_redeem-
       df_redeem-df_national-df_state)-clearinghouse_exchg-
       0.5*(cash_items)-obank_bills)-Fivepct_fund)

CRCities_data[CRCities_data$mark_dt>="1921-02-21" & CRCities_data$location!="StLouis",]$required_reserves <- 
  with(CRCities_data[CRCities_data$mark_dt>="1921-02-21" & CRCities_data$location!="StLouis",], 
       0.13*(Demand_deposits) + 0.03*(Time_deposits) + 
       0.13*(pmax(0, dt_national + dt_state + dt_non_national + Certified_checks_outstanding +
       Cashiers_checks_on_own_bank_outstanding - df_national - df_state - df_non_national -
       Items_with_Fed_in_process_of_collection - clearinghouse_exchg - 
       Checks_on_other_banks_in_same_place)))

CRCities_data[CRCities_data$mark_dt>="1921-02-21" & CRCities_data$location=="StLouis",]$required_reserves <- 
  with(CRCities_data[CRCities_data$mark_dt>="1921-02-21" & CRCities_data$location=="StLouis",], 
       0.13*(Demand_deposits) + 0.03*(Time_deposits) + 
       0.13*(pmax(0, dt_national + dt_state + dt_non_national + Certified_checks_outstanding +
       Cashiers_checks_on_own_bank_outstanding - df_national - df_state - df_non_national -
       Items_with_Fed_in_process_of_collection - clearinghouse_exchg - 
       Checks_on_other_banks_in_same_place)))

#calculates liquid assets
CRCities_data$liquid_assets <- 
  with(CRCities_data, 
       df_redeem+df_national+DuefromFed+Checks_on_other_banks_in_same_place+
       Outside_checks_other_cash_items+cash_items+US_CD+
       obank_bills+frac_curr+specie+legaltender+vault.cash)

#calculates excess liquid assets
CRCities_data$excess_liquid_assets <-
  with(CRCities_data, liquid_assets - required_reserves)

#calculates cash component of legal reserves pre-1914
CRCities_data$legal_reserves_cash <-
  with(CRCities_data, specie+legaltender+frac_curr+US_CD)

#calculates total legal reserves pre-1914
CRCities_data$legal_reserves_total <-
  with(CRCities_data, legal_reserves_cash+df_redeem)

CRCities_data[CRCities_data$mark_dt>="1921-02-21",]$legal_reserves_total <- 
CRCities_data[CRCities_data$mark_dt>="1921-02-21",]$DuefromFed

#calculates excess legal reserves
CRCities_data$excess_legal_reserves <-
  with(CRCities_data, 
       legal_reserves_total - required_reserves)

#calculates ratios over total assets
CRCities_data$liquid_assets_to_assets <-
  with(CRCities_data, liquid_assets/assets)

CRCities_data$required_reserves_to_assets <-
  with(CRCities_data, required_reserves/assets)

CRCities_data$excess_liquid_assets_to_assets <-
  with(CRCities_data, excess_liquid_assets/assets)

CRCities_data$required_reserves_to_liquid_assets <-
  with(CRCities_data, required_reserves/liquid_assets)

CRCities_data$excess_reserves_to_total_reserves <-
  with(CRCities_data, excess_legal_reserves/legal_reserves_total)

#create period variable to use in grouping
CRCities_data$period <- "1894-1914"
CRCities_data[CRCities_data$mark_dt>="1921-02-21", "period"] <- "1921-1928"

#convert central reserve city data to data.table
CRCities_table <- as.data.table(CRCities_data)

#take mean and standard deviation of central reserve city bank ratios
#including St. Louis
CRCities_table_STL <- 
  CRCities_table[, 
      .('Liquid Assets as a Share of Total Assets: Central reserve city banks (Mean)'=
          100*mean(liquid_assets_to_assets),
        'Liquid Assets as a Share of Total Assets: Central reserve city banks (SD)'=
          100*sd(liquid_assets_to_assets),
        'Required Reserves as a Share of Total Assets: Central reserve city banks (Mean)'=
          100*mean(required_reserves_to_assets),
        'Required Reserves as a Share of Total Assets: Central reserve city banks (SD)'=
          100*sd(required_reserves_to_assets),
        'Required Reserves as a Share of Liquid Assets: Central reserve city banks (Mean)'=
          100*mean(required_reserves_to_liquid_assets),
        'Required Reserves as a Share of Liquid Assets: Central reserve city banks (SD)'=
          100*sd(required_reserves_to_liquid_assets),
        'Excess Liquid Assets as a Share of Total Assets: Central reserve city banks (Mean)'=
          100*mean(excess_liquid_assets_to_assets),
        'Excess Liquid Assets as a Share of Total Assets: Central reserve city banks (SD)'=
          100*sd(excess_liquid_assets_to_assets)), 
      by=period]

#take mean and standard deviation of central reserve city bank ratios
#excluding St. Louis
CRCities_table_noSTL <- 
  CRCities_table[location!="StLouis", 
    .('Excess Reserves as a Share of Total Reserves: Central reserve city banks (Mean)'=
        100*mean(excess_reserves_to_total_reserves),
      'Excess Reserves as a Share of Total Reserves: Central reserve city banks (SD)'=
        100*sd(excess_reserves_to_total_reserves)), 
  by=period]

#merge central reserve city tables
CRCities_table <- merge(CRCities_table_STL, CRCities_table_noSTL)

#transpose central reserve city table to match format of Table 5
CRCities_table <- transp(CRCities_table)

#combine tables of each bank type into Table 5
Table5 <- rbind(Country_table, RCities_table, CRCities_table)
#convert back to data.frame
Table5 <- as.data.frame(Table5)
#reorder rows of Table 5
Table5 <- Table5[c("Liquid Assets as a Share of Total Assets: Country banks (Mean)",
                   "Liquid Assets as a Share of Total Assets: Country banks (SD)",
                   "Liquid Assets as a Share of Total Assets: Reserve city banks (Mean)",
                   "Liquid Assets as a Share of Total Assets: Reserve city banks (SD)",
                   "Liquid Assets as a Share of Total Assets: Central reserve city banks (Mean)",
                   "Liquid Assets as a Share of Total Assets: Central reserve city banks (SD)",
                   "Required Reserves as a Share of Total Assets: Country banks (Mean)",
                   "Required Reserves as a Share of Total Assets: Country banks (SD)",
                   "Required Reserves as a Share of Total Assets: Reserve city banks (Mean)",
                   "Required Reserves as a Share of Total Assets: Reserve city banks (SD)",
                   "Required Reserves as a Share of Total Assets: Central reserve city banks (Mean)",
                   "Required Reserves as a Share of Total Assets: Central reserve city banks (SD)",
                   "Required Reserves as a Share of Liquid Assets: Country banks (Mean)",
                   "Required Reserves as a Share of Liquid Assets: Country banks (SD)",
                   "Required Reserves as a Share of Liquid Assets: Reserve city banks (Mean)",
                   "Required Reserves as a Share of Liquid Assets: Reserve city banks (SD)",
                   "Required Reserves as a Share of Liquid Assets: Central reserve city banks (Mean)",
                   "Required Reserves as a Share of Liquid Assets: Central reserve city banks (SD)",
                   "Excess Liquid Assets as a Share of Total Assets: Country banks (Mean)",
                   "Excess Liquid Assets as a Share of Total Assets: Country banks (SD)",
                   "Excess Liquid Assets as a Share of Total Assets: Reserve city banks (Mean)",
                   "Excess Liquid Assets as a Share of Total Assets: Reserve city banks (SD)",
                   "Excess Liquid Assets as a Share of Total Assets: Central reserve city banks (Mean)",
                   "Excess Liquid Assets as a Share of Total Assets: Central reserve city banks (SD)",
                   "Excess Reserves as a Share of Total Reserves: Country banks (Mean)",
                   "Excess Reserves as a Share of Total Reserves: Country banks (SD)",
                   "Excess Reserves as a Share of Total Reserves: Reserve city banks (Mean)",
                   "Excess Reserves as a Share of Total Reserves: Reserve city banks (SD)",
                   "Excess Reserves as a Share of Total Reserves: Central reserve city banks (Mean)",
                   "Excess Reserves as a Share of Total Reserves: Central reserve city banks (SD)"),]


#Section 4: Generate t statistics and import them into Table 5
###############################################################################################################

#Initialize t statistic variable for Table 5
Table5$'Test statistic for difference' <- NA

####################### Section 4.1: Country banks ###################################
#create period dummy variable for country banks
Country_data$period <- 0
Country_data[Country_data$mark_dt >="1921-02-21",]$period <- 1

#stata code to run panel regression for country banks
#variable names are abbreviated automatically by the foreign package
Country_test <- 
"
encode location, generate(location_encode)

xtset mark_dt location_encode
reg liquid_assets_to_assets i.location_encode i.period, robust cluster(location_encode)
reg required_reserves_to_assets i.location_encode i.period, robust cluster(location_encode)
reg required_reserves_to_liqud_ssts i.location_encode i.period, robust cluster(location_encode)
reg excess_liquid_assets_to_assets i.location_encode i.period, robust cluster(location_encode)
reg excess_reserves_to_total_resrvs i.location_encode i.period, robust cluster(location_encode)

"

#run the above Stata code
stata(Country_test, data.in = Country_data)

#Plug t statistic from period variable regression results into Table 5
Table5["Liquid Assets as a Share of Total Assets: Country banks (Mean)", 
               "Test statistic for difference"] <- "-17.6***"
Table5["Required Reserves as a Share of Total Assets: Country banks (Mean)", 
                "Test statistic for difference"] <- "-30.8***"
Table5["Required Reserves as a Share of Liquid Assets: Country banks (Mean)", 
                "Test statistic for difference"] <- "-14.8***"
Table5["Excess Liquid Assets as a Share of Total Assets: Country banks (Mean)", 
                "Test statistic for difference"] <- "-7.0***"
Table5["Excess Reserves as a Share of Total Reserves: Country banks (Mean)", 
                "Test statistic for difference"] <- "-30.3***"

####################### Section 4.2: Reserve City banks ###################################
#create period dummy variable for reserve city banks
RCities_data$period <- 0
RCities_data[RCities_data$mark_dt >="1921-02-21",]$period <- 1

#Stata code to run panel regressions for reserve city banks
#variable names are abbreviated automatically by the foreign package
RCities_test <- 
"
encode location, generate(location_encode)

xtset mark_dt location_encode
reg liquid_assets_to_assets i.location_encode i.period, robust cluster(location_encode)
reg required_reserves_to_assets i.location_encode i.period, robust cluster(location_encode)
reg required_reserves_to_liqud_ssts i.location_encode i.period, robust cluster(location_encode)
reg excess_liquid_assets_to_assets i.location_encode i.period, robust cluster(location_encode)
reg excess_reserves_to_total_resrvs i.location_encode i.period, robust cluster(location_encode)
"

#run the above Stata code
stata(RCities_test, data.in = RCities_data)

#Plug t statistic from period variable regression results into Table 5
Table5["Liquid Assets as a Share of Total Assets: Reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-18.8***"
Table5["Required Reserves as a Share of Total Assets: Reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-34.0***"
Table5["Required Reserves as a Share of Liquid Assets: Reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-3.5***"
Table5["Excess Liquid Assets as a Share of Total Assets: Reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-6.9***"
Table5["Excess Reserves as a Share of Total Reserves: Reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-10.0***"

####################### Section 4.3: Central Reserve City banks #############################
#create period dummy variables for central reserve city banks
CRCities_data$period <- 0
CRCities_data[CRCities_data$mark_dt >="1921-02-21",]$period <- 1

#Stata code to run panel regression for central reserve city banks
#variable names are abbreviated automatically by the foreign package
CRCities_test <- 
'
encode location, generate(location_encode)

xtset mark_dt location_encode
reg liquid_assets_to_assets i.location_encode i.period, robust cluster(location_encode)
reg required_reserves_to_assets i.location_encode i.period, robust cluster(location_encode)
reg required_reserves_to_liqud_ssts i.location_encode i.period, robust cluster(location_encode)
reg excess_liquid_assets_to_assets i.location_encode i.period, robust cluster(location_encode)
reg excess_reserves_to_total_resrvs i.location_encode i.period if location!="StLouis", robust cluster(location_encode)
'

#run the above Stata code
stata(CRCities_test, data.in = CRCities_data)

#Plug t statistic from period variable regression results into Table 5
Table5["Liquid Assets as a Share of Total Assets: Central reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-12.8***"
Table5["Required Reserves as a Share of Total Assets: Central reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-13.9***"
Table5["Required Reserves as a Share of Liquid Assets: Central reserve city banks (Mean)", 
                "Test statistic for difference"] <- "1.6"
Table5["Excess Liquid Assets as a Share of Total Assets: Central reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-4.0*"
Table5["Excess Reserves as a Share of Total Reserves: Central reserve city banks (Mean)", 
                "Test statistic for difference"] <- "-7.4*"

#Export Table 5 to .csv
write.csv(Table5, file = "output/MS16-292Table 5.csv")